@@ -20,7 +20,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
 
 // http://www.cs.rpi.edu/~musser/archive/2005/gsd/restricted/FloydWarshall/FloydWarshall.pdf
 
@@ -44,6 +44,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include "cpp_common/basePath_SSEC.hpp"
 #include "cpp_common/pgr_base_graph.hpp"
+#include "cpp_common/interruption.h"
 
 // TODO(vicky) don't keep it here
 #include "cpp_common/pgr_alloc.hpp"
@@ -99,6 +100,10 @@ class Pgr_allpairs {
          std::vector< std::vector<double>> matrix;
          make_matrix(graph.num_vertices(), matrix);
          inf_plus<double> combine;
+
+         /* abort in case of an interruption occurs (e.g. the query is being cancelled) */
+         CHECK_FOR_INTERRUPTS();
+
          boost::floyd_warshall_all_pairs_shortest_paths(
                  graph.graph,
                  matrix,
@@ -116,6 +121,10 @@ class Pgr_allpairs {
          std::vector< std::vector<double>> matrix;
          make_matrix(graph.num_vertices(), matrix);
          inf_plus<double> combine;
+
+         /* abort in case of an interruption occurs (e.g. the query is being cancelled) */
+         CHECK_FOR_INTERRUPTS();
+
          boost::floyd_warshall_all_pairs_shortest_paths(
                  graph.graph,
                  matrix,
@@ -134,6 +143,10 @@ class Pgr_allpairs {
          std::vector< std::vector<double>> matrix;
          make_matrix(graph.num_vertices(), matrix);
          inf_plus<double> combine;
+
+         /* abort in case of an interruption occurs (e.g. the query is being cancelled) */
+         CHECK_FOR_INTERRUPTS();
+
          boost::johnson_all_pairs_shortest_paths(
                  graph.graph,
                  matrix,
@@ -152,6 +165,10 @@ class Pgr_allpairs {
          std::vector< std::vector<double>> matrix;
          make_matrix(graph.num_vertices(), matrix);
          inf_plus<double> combine;
+
+         /* abort in case of an interruption occurs (e.g. the query is being cancelled) */
+         CHECK_FOR_INTERRUPTS();
+
          boost::johnson_all_pairs_shortest_paths(
                  graph.graph,
                  matrix,
