@@ -1,6 +1,6 @@
 /*PGR-GNU*****************************************************************
 
-File: pgr_bdDijkstra.hpp 
+File: pgr_bdDijkstra.hpp
 
 Copyright (c) 2016 Celia Virginia Vergara Castillo
 vicky_vergara@hotmail.com
@@ -84,9 +84,6 @@ class Pgr_bdDijkstra : public Pgr_bidirectional<G> {
          v_source = start_vertex;
          v_target = end_vertex;
 
-         if (v_source == v_target) {
-            return Path(v_source, v_target);
-         }
          return bidirectional(only_cost);
      }
 
