@@ -91,17 +91,17 @@ class Pgr_edwardMoore {
         std::vector<double> current_cost(graph.num_vertices(), std::numeric_limits<double>::infinity());
         std::vector<bool> isInQ(graph.num_vertices(), false);
         std::vector<E> from_edge(graph.num_vertices());
-        std::deque<int64_t> dq;
+        std::deque<V> dq;
         DEFAULT_EDGE = from_edge[0];
 
-        int64_t bgl_start_vertex = graph.get_V(start_vertex);
+        auto bgl_start_vertex = graph.get_V(start_vertex);
 
         current_cost[bgl_start_vertex] = 0;
         isInQ[bgl_start_vertex] = true;
         dq.push_front(bgl_start_vertex);
 
         while (dq.empty() == false) {
-            int64_t head_vertex = dq.front();
+            auto head_vertex = dq.front();
 
             dq.pop_front();
             isInQ[head_vertex] = false;
@@ -114,7 +114,7 @@ class Pgr_edwardMoore {
                 continue;
             }
 
-            int64_t bgl_target_vertex = graph.get_V(target_vertex);
+            auto bgl_target_vertex = graph.get_V(target_vertex);
 
             if (from_edge[bgl_target_vertex] == DEFAULT_EDGE) {
                 continue;
@@ -129,12 +129,12 @@ class Pgr_edwardMoore {
 
     Path getPath(
         G &graph,
-        int64_t bgl_start_vertex,
+        V bgl_start_vertex,
         int64_t target,
-        int64_t bgl_target_vertex,
+        V bgl_target_vertex,
         std::vector<E> &from_edge,
         std::vector<double> &current_cost) {
-        int64_t current_node = bgl_target_vertex;
+        auto current_node = bgl_target_vertex;
 
         Path path = Path(graph[bgl_start_vertex].id, graph[current_node].id);
 
@@ -158,8 +158,8 @@ class Pgr_edwardMoore {
         std::vector<double> &current_cost,
         std::vector<bool> &isInQ,
         std::vector<E> &from_edge,
-        std::deque<int64_t> &dq,
-        int64_t &head_vertex) {
+        std::deque<V> &dq,
+        V &head_vertex) {
         /* abort in case of an interruption occurs (e.g. the query is being cancelled) */
         CHECK_FOR_INTERRUPTS();
 
