@@ -20,7 +20,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
 
 #ifndef INCLUDE_C_COMMON_ARRAYS_INPUT_H_
 #define INCLUDE_C_COMMON_ARRAYS_INPUT_H_
@@ -28,25 +28,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
 #include <stdint.h>
-
-// first file to include
-#ifdef __GNUC__
-#if __GNUC__ > 5
-#pragma GCC diagnostic ignored "-Wpedantic"
-#else
-#pragma GCC diagnostic ignored "-pedantic"
-#endif
-#endif
-
 #include <postgres.h>
-
-#ifdef __GNUC__
-#pragma GCC diagnostic pop
-#endif
-
-// for ArrayType
-#include "utils/array.h"
-
+#include <utils/array.h>
 
 /** @brief enforces the input array to be @b NOT empty */
 int64_t* pgr_get_bigIntArray(size_t *arrlen, ArrayType *input);
