@@ -20,12 +20,15 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
 
 #ifndef INCLUDE_C_COMMON_RESTRICTIONS_INPUT_H_
 #define INCLUDE_C_COMMON_RESTRICTIONS_INPUT_H_
 #pragma once
 
+/* for size-t */
+#include <stddef.h>
+
 #include "c_types/restriction_t.h"
 
 void pgr_get_restrictions(
