@@ -39,6 +39,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include "c_types/general_path_element_t.h"
 #include "c_types/pgr_edge_t.h"
 #include "c_types/pgr_flow_t.h"
+#include "cpp_common/pgr_assert.h"
+#include "cpp_common/identifiers.hpp"
+
 
 namespace pgrouting {
 namespace graph {
@@ -49,111 +52,130 @@ class PgrDirectedChPPGraph {
              const pgr_edge_t *dataEdges,
              const size_t totalEdges);
 
-     double DirectedChPP() {
-         double minAddedCost = flowGraph.MinCostMaxFlow();
-         int64_t maxFlow = flowGraph.GetMaxFlow();
-         if (maxFlow == totalDeg)
-             return minAddedCost + totalCost;
-         return -1.0;
+     double DirectedChPP() const {
+         return m_cost;
      }
 
-     std::vector<General_path_element_t> GetPathEdges();
+     std::vector<General_path_element_t> GetPathEdges() const {
+         return resultPath;
+     }
+
+      ~PgrDirectedChPPGraph();
+
 
  private:
      bool EulerCircuitDFS(int64_t p);
      void BuildResultGraph();
      void BuildResultPath();
-     bool JudgeCoveredAllEdges();
+     void setPathEdges(graph::PgrCostFlowGraph &flowGraph);
 
  private:
      int64_t totalDeg;
      double totalCost;
      int64_t superSource, superTarget;
      int64_t startPoint;
+     double m_cost;
+     Identifiers<int64_t> vertices;
 
+     /** (source, target) -> idx to originalEdges;
+      * Only the one with the lower cost is kept
+      */
+     std::map<std::pair<int64_t, int64_t>, const pgr_edge_t*> edgeToIdx;
      std::map<std::pair<int64_t, int64_t>,  // source, target
               size_t> edgeToId;  // index in resultEdges
 
-     graph::PgrCostFlowGraph flowGraph;
+     std::vector<pgr_edge_t> originalEdges;
      std::vector<pgr_edge_t> resultEdges;
 
-     std::vector<std::pair<int64_t, std::vector<size_t> > > resultGraph;
+     /** vector of vertex -> vector of edges **/
+     std::vector<std::pair<int64_t, std::vector<size_t>>> resultGraph;
      std::map<int64_t, size_t> VToVecid;
-     std::vector<bool> edgeVisited;
+     Identifiers<size_t> edgeVisited;
+     Identifiers<int64_t> vertexVisited;
 
      std::stack<int64_t> pathStack;  // node stack
      std::vector<General_path_element_t> resultPath;
+
+     /* for the flow graph */
+     std::vector<pgr_costFlow_t> edges;
+     std::set<int64_t> sources;
+     std::set<int64_t> targets;
 };
 
+PgrDirectedChPPGraph::~PgrDirectedChPPGraph() {
+    edgeToIdx.clear();
+}
 PgrDirectedChPPGraph::PgrDirectedChPPGraph(
         const pgr_edge_t *dataEdges,
         const size_t totalEdges) :
-    totalCost(0) {
-    resultEdges.clear();
-    for (size_t i = 0; i < totalEdges; i++) {
-        pgr_edge_t edge;
-        edge.id = dataEdges[i].id;
-        edge.source = dataEdges[i].source;
-        edge.target = dataEdges[i].target;
-        edge.reverse_cost = -1.0;
+    totalDeg(0), totalCost(0), vertices(),
+    edgeToIdx(), originalEdges(),
+    resultGraph(), VToVecid(), edgeVisited(),
+    pathStack(), resultPath(),
+    edges(), sources(), targets()
+{
+    pgassert(totalEdges > 0);
+    pgassert(pathStack.empty());
+
+    pgassert(originalEdges.empty());
+    startPoint = dataEdges[0].source;
+    for (size_t i = 0; i < totalEdges; ++i) {
         if (dataEdges[i].cost > 0) {
-            startPoint = edge.source;
-            edge.cost = dataEdges[i].cost;
+            auto edge(dataEdges[i]);
+            edge.reverse_cost = -1.0;
             totalCost += edge.cost;
-            resultEdges.push_back(edge);
+            originalEdges.push_back(edge);
+            vertices += dataEdges[i].source;
+            vertices += dataEdges[i].target;
         }
         if (dataEdges[i].reverse_cost > 0) {
+            auto edge(dataEdges[i]);
             std::swap(edge.source, edge.target);
-            edge.cost = dataEdges[i].reverse_cost;
+            std::swap(edge.cost, edge.reverse_cost);
+            edge.reverse_cost = -1.0;
             totalCost += edge.cost;
-            resultEdges.push_back(edge);
+            originalEdges.push_back(edge);
+            vertices += dataEdges[i].source;
+            vertices += dataEdges[i].target;
+            pgassert(dataEdges[i].source == edge.target);
+            pgassert(dataEdges[i].target == edge.source);
         }
     }
 
-    std::vector<pgr_costFlow_t> edges;
-    std::set<int64_t> sources;
-    std::set<int64_t> targets;
-
     // calcu deg & build part of edges
     std::map<int64_t, int> deg;
-    for (size_t i = 0; i < resultEdges.size(); i++) {
-        deg[resultEdges[i].source]++;
-        deg[resultEdges[i].target]--;
+    size_t i(0);
+    for (const auto &e : originalEdges) {
+        pgassert(e.cost > 0);
+        /* has out going edge */
+        deg[e.source]++;
+        /* has out incoming edge */
+        deg[e.target]--;
 
-        if (edgeToId.find(std::make_pair(resultEdges[i].source, resultEdges[i].target)) ==
-                edgeToId.end()) {
-            edgeToId.insert(std::make_pair(std::make_pair(resultEdges[i].source, resultEdges[i].target), i));
+        auto current_edge(std::make_pair(e.source, e.target));
+        if (edgeToIdx.find(current_edge) == edgeToIdx.end()) {
+            edgeToIdx[current_edge] = &e;
         } else {
-            if (resultEdges[edgeToId[
-                    std::make_pair(resultEdges[i].source, resultEdges[i].target)]].cost >
-                    resultEdges[i].cost) {
-                edgeToId[std::make_pair(resultEdges[i].source, resultEdges[i].target)] = i;
+            if (edgeToIdx[current_edge]->cost > e.cost) {
+                edgeToIdx[current_edge] = &e;
             }
         }
 
         pgr_costFlow_t edge;
-        edge.edge_id = resultEdges[i].id;
+        edge.edge_id = e.id;
         edge.reverse_capacity = -1;
         edge.reverse_cost = -1.0;
-        edge.source = resultEdges[i].source;
-        edge.target = resultEdges[i].target;
+        edge.source = e.source;
+        edge.target = e.target;
         edge.capacity = (std::numeric_limits<int32_t>::max)();
-        edge.cost = resultEdges[i].cost;
+        edge.cost = e.cost;
         edges.push_back(edge);
+        ++i;
     }
 
-    // find superSource & superTarget
-    superSource = superTarget = -1;
-    int64_t iPointId = 1;
-    while (superSource == -1 || superTarget == -1) {
-        if (deg.find(iPointId) == deg.end()) {
-            if (superSource == -1)
-                superSource = iPointId;
-            else
-                superTarget = iPointId;
-        }
-        iPointId++;
-    }
+    superSource = deg.rbegin()->first + 1;
+    superTarget = deg.rbegin()->first + 2;
+
     sources.insert(superSource);
     targets.insert(superTarget);
 
@@ -183,58 +205,71 @@ PgrDirectedChPPGraph::PgrDirectedChPPGraph(
         edges.push_back(edge);
     }
 
-    PgrCostFlowGraph graph(edges, sources, targets);
-    flowGraph = graph;
+    PgrCostFlowGraph flowGraph(edges, sources, targets);
+    pgassert(pathStack.empty());
+    try {
+        pgrouting::graph::PgrCostFlowGraph digraph1(edges, sources, targets);
+        auto minAddedCost = digraph1.MinCostMaxFlow();
+        auto maxFlow = digraph1.GetMaxFlow();
+        m_cost = (maxFlow == totalDeg)? minAddedCost + totalCost : -1.0;
+    } catch (...) {
+        m_cost = -1;
+    }
+    setPathEdges(flowGraph);
 }
 
-bool
-PgrDirectedChPPGraph::JudgeCoveredAllEdges() {
-    for (const auto b : edgeVisited)
-        if (!b)
-            return false;
-    return true;
-}
 
-std::vector<General_path_element_t>
-PgrDirectedChPPGraph::GetPathEdges() {
+void
+PgrDirectedChPPGraph::setPathEdges(graph::PgrCostFlowGraph &flowGraph) {
+    pgassert(pathStack.empty());
+    resultPath.clear();
+    if (m_cost == -1) return;
     // catch new edges
-    std::vector<pgr_flow_t> addedEdges = flowGraph.GetFlowEdges();
-    for (auto &flow_t : addedEdges) {
-        if (flow_t.source != superSource && flow_t.source != superTarget) {
-            if (flow_t.target != superSource && flow_t.target != superTarget) {
-                pgr_edge_t newEdge;
-                newEdge.source = flow_t.source;
-                newEdge.target = flow_t.target;
-                newEdge.id =
-                    resultEdges[edgeToId[std::make_pair(
-                            newEdge.source,
-                            newEdge.target)]].id;
-                newEdge.cost =
-                    resultEdges[edgeToId[std::make_pair(
-                            newEdge.source,
-                            newEdge.target)]].cost;
-                newEdge.reverse_cost = -1.0;
-                while (flow_t.flow--)
-                    resultEdges.push_back(newEdge);
+    try {
+        flowGraph.MinCostMaxFlow();
+        flowGraph.GetMaxFlow();
+        std::vector<pgr_flow_t> addedEdges = flowGraph.GetFlowEdges();
+        resultEdges = originalEdges;
+        for (auto &flow_t : addedEdges) {
+            if (flow_t.source != superSource && flow_t.source != superTarget
+                    && flow_t.target != superSource && flow_t.target != superTarget) {
+                auto current_edge(std::make_pair(flow_t.source, flow_t.target));
+                pgr_edge_t newEdge = *edgeToIdx[current_edge];
+                /* adding edges that need to be traversed twice */
+                while (flow_t.flow--) resultEdges.push_back(newEdge);
             }
         }
+    } catch (...) {
+        resultPath.clear();
+        return;
     }
 
+    pgassert(pathStack.empty());
     BuildResultGraph();
 
+    pgassert(pathStack.empty());
+    pgassert(edgeVisited.empty());
+
+
     EulerCircuitDFS(startPoint);
 
+    if (!(vertices - vertexVisited).empty()) {
+        resultPath.clear();
+        return;
+    }
+    pgassert(!pathStack.empty());
+
     BuildResultPath();
 
-    if (!JudgeCoveredAllEdges())
-        resultPath.clear();
-    return resultPath;
+
+    return;
 }
 
 void
 PgrDirectedChPPGraph::BuildResultPath() {
-    if (pathStack.empty())
-        return;
+    if (pathStack.empty()) return;
+    pgassert(resultPath.empty());
+
     int64_t preNode = pathStack.top();
     pathStack.pop();
 
@@ -242,18 +277,18 @@ PgrDirectedChPPGraph::BuildResultPath() {
     while (!pathStack.empty()) {
         int64_t nowNode = pathStack.top();
         pathStack.pop();
-        pgr_edge_t edge_t =
-            resultEdges[edgeToId[std::make_pair(preNode, nowNode)]];
+
+        auto edge_t = *edgeToIdx[std::make_pair(preNode, nowNode)];
         newElement.node = edge_t.source;
         newElement.edge = edge_t.id;
         newElement.cost = edge_t.cost;
         if (resultPath.empty()) {
+            /* adding the first row because is a cycle */
             newElement.seq = 1;
             newElement.agg_cost = 0.0;
         } else {
             newElement.seq = resultPath.back().seq + 1;
-            newElement.agg_cost =
-                resultPath.back().agg_cost + resultPath.back().cost;
+            newElement.agg_cost = resultPath.back().agg_cost + resultPath.back().cost;
         }
         resultPath.push_back(newElement);
         preNode = nowNode;
@@ -276,37 +311,34 @@ PgrDirectedChPPGraph::BuildResultPath() {
 // TODO(mg) find suitable API in BGL, maybe DfsVisitor will work.
 // Implement DFS without BGL for now
 bool
-PgrDirectedChPPGraph::EulerCircuitDFS(int64_t p) {
-    for (auto iter = resultGraph[VToVecid[p]].second.begin();
-         iter != resultGraph[VToVecid[p]].second.end();
-         ++iter) {
-        if (!edgeVisited[*iter]) {
-            edgeVisited[*iter] = true;
-            EulerCircuitDFS(resultEdges[*iter].target);
+PgrDirectedChPPGraph::EulerCircuitDFS(int64_t vertex) {
+    for (const auto e : resultGraph[VToVecid[vertex]].second) {
+        if (!edgeVisited.has(e)) {
+            edgeVisited += e;
+            EulerCircuitDFS(resultEdges[e].target);
         }
     }
-    pathStack.push(p);
+    pathStack.push(vertex);
+    vertexVisited += vertex;
     return true;
 }
 
 void
 PgrDirectedChPPGraph::BuildResultGraph() {
+    pgassert(resultGraph.empty());
+    pgassert(VToVecid.empty());
     resultGraph.clear();
     VToVecid.clear();
-    edgeVisited.clear();
-    for (size_t i = 0; i < resultEdges.size(); i++) {
-        pgr_edge_t edge_t = resultEdges[i];
-        edgeVisited.push_back(false);
+    size_t e_id(0);
+    for (const auto &edge_t : resultEdges) {
         if (VToVecid.find(edge_t.source) == VToVecid.end()) {
-            VToVecid.insert(
-                    std::pair<int64_t, size_t>(
-                        edge_t.source,
-                        resultGraph.size()));
+            VToVecid[edge_t.source] = resultGraph.size();
             resultGraph.resize(resultGraph.size() + 1);
         }
         size_t vid = VToVecid[edge_t.source];
-        resultGraph[vid].second.push_back(i);
+        resultGraph[vid].second.push_back(e_id);
         resultGraph[vid].first = edge_t.source;
+        ++e_id;
     }
 }
 
