@@ -6,19 +6,19 @@
 
  ------
 
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
 
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+GNU General Public License for more details.
 
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  ********************************************************************PGR-GNU*/
 
@@ -28,26 +28,15 @@
 #define INCLUDE_CPP_COMMON_XY_VERTEX_H_
 #pragma once
 
-#ifdef Max
-#undef Max
-#endif
-#ifdef Min
-#undef Min
-#endif
 
-#include <CGAL/Simple_cartesian.h>
 #include <vector>
 
+#include "cpp_common/bpoint.hpp"
 #include "c_types/pgr_edge_xy_t.h"
 
 
 namespace pgrouting {
 
-// typedef boost::geometry::model::d2::point_xy<double> Point;
-typedef CGAL::Simple_cartesian<double> Simple_cartasian;
-typedef Simple_cartasian::Point_2  Point;
-
-
 class XY_vertex {
  public:
   XY_vertex() = default;
@@ -58,7 +47,7 @@ class XY_vertex {
 
   XY_vertex(const Pgr_edge_xy_t &other, bool is_source) :
       id(is_source? other.source : other.target),
-      point(is_source? Point(other.x1, other.y1) : Point(other.x2, other.y2))
+      point(is_source? Bpoint(other.x1, other.y1) : Bpoint(other.x2, other.y2))
       {}
 
 
@@ -75,7 +64,7 @@ class XY_vertex {
 
  public:
   int64_t id;
-  Point point;
+  Bpoint point;
 };
 
 size_t
@@ -83,7 +72,7 @@ check_vertices(std::vector < XY_vertex > vertices);
 
 std::vector < XY_vertex >
 extract_vertices(
-    const Pgr_edge_xy_t *data_edges, int64_t count);
+    const Pgr_edge_xy_t *data_edges, size_t count);
 
 std::vector < XY_vertex >
 extract_vertices(
