@@ -20,12 +20,19 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
 
 #ifndef INCLUDE_DRIVERS_YEN_KSP_DRIVER_H_
 #define INCLUDE_DRIVERS_YEN_KSP_DRIVER_H_
 #pragma once
 
+/* for size-t */
+#ifdef __cplusplus
+#   include <cstddef>
+#else
+#   include <stddef.h>
+#endif
+
 #include "c_types/pgr_edge_t.h"
 #include "c_types/general_path_element_t.h"
 
@@ -39,7 +46,7 @@ extern "C" {
             size_t total_edges,
             int64_t  start_vid,
             int64_t end_vid,
-            int no_paths,
+            size_t K,
             bool directed,
             bool heap_paths,
             General_path_element_t **return_tuples,
