@@ -25,42 +25,54 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 /*! @file dnode.h */
 
-#ifndef INCLUDE_PICKDELIVER_DNODE_H_
-#define INCLUDE_PICKDELIVER_DNODE_H_
+#ifndef INCLUDE_VRP_DNODE_H_
+#define INCLUDE_VRP_DNODE_H_
 #pragma once
 
 #include <string>
 #include <iosfwd>
-#include "vrp/base_node.h"
-#include "vrp/pd_problem.h"
+#include "cpp_common/identifier.h"
+#include "cpp_common/pgr_messages.h"
 
 namespace pgrouting {
 namespace vrp {
 
+class Pgr_pickDeliver;
+class PD_problem;
+
 /*! @class Dnode
  * @brief The Dnode class defines a the basic operations when data is a matrix.
  *
  * currently needs the PD_problem
  */
-class Dnode : public Base_node, public PD_problem {
+class Dnode : public Identifier {
+    friend PD_problem;
+
  public:
      /*! @name constructors
       * @{
       */
      Dnode() = default;
      /*! @brief data constructor */
-     Dnode(size_t id, int64_t original_id, double, double);
+     Dnode(size_t id, int64_t original_id);
      /*!@}*/
 
 
-     using Base_node::operator==;
+     bool operator==(const Dnode &other) const;
 
-     double distance(const Base_node *) const;
+     double distance(const Dnode &other) const;
 
      friend std::ostream& operator << (std::ostream &log, const Dnode &node);
+
+ protected:
+     static Pgr_messages& msg() ;
+
+     /** The problem */
+     static Pgr_pickDeliver* problem;
+
 };
 
 }  // namespace vrp
 }  // namespace pgrouting
 
-#endif  // INCLUDE_PICKDELIVER_DNODE_H_
+#endif  // INCLUDE_VRP_DNODE_H_
