@@ -30,7 +30,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #pragma once
 
 #include "vrp/optimize.h"
-#include "vrp/book_keeping.h"
 
 namespace pgrouting {
 namespace vrp {
@@ -66,7 +65,7 @@ class Optimize : public Solution {
      bool move_reduce_cost(Vehicle_pickDeliver &from, Vehicle_pickDeliver &to);
      bool inter_swap();
 
-     void move_order(
+     bool move_order(
              Order order,
              Vehicle_pickDeliver &from_truck,
              Vehicle_pickDeliver &to_truck);
@@ -78,8 +77,10 @@ class Optimize : public Solution {
              Vehicle_pickDeliver &to_truck);
      void save_if_best();
 
+#if 0
  private:
      Swap_bk p_swaps;
+#endif
 };
 
 }  //  namespace vrp
