@@ -46,7 +46,10 @@ namespace vrp {
 class Order;
 class Vehicle_node;
 
-class PD_Orders : public PD_problem {
+class PD_Orders {
+    /** PD_rpblem needs access to set up the problem pointer */
+     friend class PD_problem;
+
      typedef std::vector<Order> Orders;
 
  public:
@@ -55,7 +58,7 @@ class PD_Orders : public PD_problem {
 
  public:
      /*! @name constructors
-      * @{ 
+      * @{
       */
      PD_Orders() = default;
      PD_Orders(const PD_Orders&) = default;
@@ -88,35 +91,19 @@ class PD_Orders : public PD_problem {
 
      void add_order(
              const PickDeliveryOrders_t &,
-             std::unique_ptr<Base_node>,
              const Vehicle_node&,
-             std::unique_ptr<Base_node>,
              const Vehicle_node&);
 
-     template <typename T> std::unique_ptr<Base_node> create_b_pick(
-             const PickDeliveryOrders_t &order,
-             size_t node_id) {
-         std::unique_ptr<Base_node> b_pick(new T(
-                     node_id,
-                     order.pick_node_id,
-                     order.pick_x,
-                     order.pick_y));
-         return std::move(b_pick);
-     }
-
-     template <typename T> std::unique_ptr<Base_node> create_b_deliver(
-             const PickDeliveryOrders_t &order,
-             size_t node_id) {
-         std::unique_ptr<Base_node> b_drop(new T(
-                     node_id,
-                     order.deliver_node_id,
-                     order.deliver_x,
-                     order.deliver_y));
-         return std::move(b_drop);
-     }
 
  private:
      Orders m_orders;
+
+     /** @brief Access to the problem's message */
+     Pgr_messages& msg() const;
+
+     /** The problem */
+     static Pgr_pickDeliver* problem;
+
 };
 
 }  //  namespace vrp
