@@ -30,6 +30,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #pragma once
 
 #include "cpp_common/pgr_messages.h"
+#include "vrp/initials_code.h"
 
 
 
@@ -40,15 +41,15 @@ class Pgr_pickDeliver;
 
 class PD_problem {
  public:
+
+    /** @brief Initializing the problem pointer */
     explicit PD_problem(Pgr_pickDeliver* p_problem);
-    PD_problem(const PD_problem &problem);
-    PD_problem() { }
 
- public:
-     static Pgr_messages msg;
+    /** @brief Not wllowing to copy the problem */
+    PD_problem(const PD_problem &problem) = delete;
 
- protected:
-     static Pgr_pickDeliver* problem;
+    /** @brief Not allwing initialization without information */
+    PD_problem() = delete;
 };
 
 }  //  namespace vrp
