@@ -35,30 +35,44 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <memory>
 #include <utility>
 
-#include "c_types/pickDeliver/general_vehicle_orders_t.h"
-#include "c_types/pickDeliver/vehicle_t.h"
 #include "c_types/pickDeliver/pickDeliveryOrders_t.h"
-#include "cpp_common/identifiers.hpp"
+#include "c_types/pickDeliver/vehicle_t.h"
+#include "c_types/pickDeliver/general_vehicle_orders_t.h"
+#include "vrp/pd_problem.h"
 #include "cpp_common/Dmatrix.h"
-#include "vrp/fleet.h"
 #include "vrp/pd_orders.h"
+#include "vrp/fleet.h"
 #include "vrp/solution.h"
+#if 0
+#include "cpp_common/identifiers.hpp"
+#endif
 
 namespace pgrouting {
 namespace vrp {
 
 class Order;
 class Vehicle_node;
-class Base_node;
+
+class Dnode;
+class Solution;
+class Initial_solution;
 
 class Pgr_pickDeliver : public PD_problem {
+    friend Fleet;
+    friend Dnode;
+    friend PD_Orders;
+    friend Solution;
+    friend Initial_solution;
+
  public:
+#if 0
     Pgr_pickDeliver(
             const std::vector<PickDeliveryOrders_t> &pd_orders,
             const std::vector<Vehicle_t> &vehicles,
             double factor,
             size_t max_cycles,
             int initial);
+#endif
 
     Pgr_pickDeliver(
             const std::vector<PickDeliveryOrders_t> &pd_orders,
@@ -77,15 +91,21 @@ class Pgr_pickDeliver : public PD_problem {
     Solution optimize(const Solution init_solution);
     size_t max_cycles() const {return m_max_cycles;}
 
+#if 0
     inline size_t& node_id() {return m_node_id;}
+#endif
 
-    void add_node(const Vehicle_node &node) {
-        m_nodes.push_back(node);
-    }
+    void add_node(const Vehicle_node &node);
 
+#if 0
     void add_base_node(std::unique_ptr<Base_node> node_ptr) {
         m_base_nodes.push_back(std::move(node_ptr));
     }
+#endif
+
+    Initials_code get_kind() const {
+        return (Initials_code) m_initial_id;
+    }
 
 #if 1
     // TODO(vicky) delete this function
@@ -93,6 +113,11 @@ class Pgr_pickDeliver : public PD_problem {
 #endif
     Fleet trucks() const {return m_trucks;}
 
+    /** message controller for all classes */
+    Pgr_messages msg;
+    /** @} */
+
+
  private:
     //! used define the initial solution algorithm to be used
     int m_initial_id;
@@ -100,14 +125,18 @@ class Pgr_pickDeliver : public PD_problem {
     //! maximum cycles in the optimization
     size_t m_max_cycles;
 
+#if 0
     //! used to keep track of the next id the node gets in the eucledian version
     size_t m_node_id;
+#endif
 
-    std::vector<Vehicle_node> m_nodes;
 
  public:
     // TODO(vicky) make this private
+    std::vector<Vehicle_node> m_nodes;
+#if 0
     std::vector<std::unique_ptr<Base_node>> m_base_nodes;
+#endif
     pgrouting::tsp::Dmatrix m_cost_matrix;
 
  private:
