@@ -45,6 +45,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 namespace pgrouting {
 namespace vrp {
 
+class Pgr_pickDeliver;
+
 
 /*! @class Vehicle
  *  @brief Vehicle with time windows
@@ -69,11 +71,15 @@ namespace vrp {
  * @sa @ref Vehicle_node
  */
 
-class Vehicle : public Identifier, public PD_problem {
+class Vehicle : public Identifier {
  protected:
      typedef size_t POS;
+     using difference_type = std::deque<Vehicle_node>::difference_type;
      std::deque< Vehicle_node > m_path;
 
+     friend class PD_problem;
+
+
  private:
      double m_capacity;
      double m_factor;
@@ -87,10 +93,10 @@ class Vehicle : public Identifier, public PD_problem {
      std::vector<General_vehicle_orders_t>
            get_postgres_result(int vid) const;
 
-     Vehicle(const Vehicle &);
+     Vehicle(const Vehicle &) = default;
      Vehicle(
              size_t idx,
-             int64_t kind,
+             int64_t id,
              const Vehicle_node &starting_site,
              const Vehicle_node &ending_site,
              double p_capacity,
@@ -220,6 +226,15 @@ class Vehicle : public Identifier, public PD_problem {
       */
      bool empty() const;
 
+     /*! @brief return number of nodes in the truck
+      *
+      * ~~~~{.c}
+      * True: S E
+      * False: S <nodes> E
+      * ~~~~
+      */
+     size_t size() const;
+
 
      /// @{
      Cost cost() const;
@@ -344,8 +359,17 @@ class Vehicle : public Identifier, public PD_problem {
 
 
      std::pair<POS, POS> position_limits(const Vehicle_node node) const;
+     std::pair<POS, POS> drop_position_limits(const Vehicle_node node) const;
+
+
+     /** Pointer to problem */
+     static Pgr_pickDeliver* problem;
+
+     /** @brief Access to the problem's message */
+     static Pgr_messages& msg();
 
  private:
+     POS getDropPosLowLimit(const Vehicle_node &node) const;
      POS getPosLowLimit(const Vehicle_node &node) const;
      POS getPosHighLimit(const Vehicle_node &node) const;
 };
