@@ -34,6 +34,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include "vrp/pd_orders.h"
 #include "vrp/tw_node.h"
 #include "vrp/vehicle.h"
+#include "vrp/initials_code.h"
 #include "cpp_common/identifiers.hpp"
 
 namespace pgrouting {
@@ -58,8 +59,8 @@ class Vehicle_pickDeliver : public Vehicle {
      friend class Optimize;
 
      Vehicle_pickDeliver(
-             size_t id,
-             size_t kind,
+             size_t idx,
+             int64_t id,
              const Vehicle_node &starting_site,
              const Vehicle_node &ending_site,
              double p_capacity,
@@ -139,7 +140,29 @@ class Vehicle_pickDeliver : public Vehicle {
       * Can generate time window violation
       * No capacity violation
       */
-     void insert(const Order &order);
+     bool insert(const Order &order);
+
+     /*! @brief Inserts an order In semi-Lifo order
+      *
+      * Precondition:
+      * !has_order(order)
+      *
+      * Postcondition:
+      * has_order(order)
+      * !has_cv();
+      *
+      * ~~~~{.c}
+      * Before: S .... (P1 ....... P2) ... D2 .... D1 .... E
+      *  After: S .... (P .. P1 .. P2) ... D2 .. D .. D1 .... E
+      * ~~~~
+      *
+      * push_back is performed when
+      *   - drop generates a time window violation
+      *
+      * Can generate time window violation
+      * No capacity violation
+      */
+     bool semiLIFO(const Order &order);
 
 #if 0
      void insert_while_compatibleJ(
@@ -156,13 +179,13 @@ class Vehicle_pickDeliver : public Vehicle {
       */
      void erase(const Order &order);
 
-     /* @brief 
+     /* @brief
       */
      Order get_first_order() const;
      Order get_worse_order(Identifiers<size_t> of_this_subset) const;
 
      void do_while_feasable(
-             int kind,
+             Initials_code kind,
              Identifiers<size_t> &unassigned,
              Identifiers<size_t> &assigned);
 
