@@ -1,5 +1,6 @@
 \i setup.sql
 
+UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
 SELECT plan(3);
 
 --DROP TABLE nodes;
@@ -35,25 +36,32 @@ copy nodes(id,x,y) FROM stdin WITH DELIMITER '|';
 
 
 PREPARE q1 AS
-SELECT * FROM pgr_alphaShape('select * from nodes where id = 161');
+SELECT * FROM pgr_alphaShape((SELECT ST_Collect(ST_MakePoint(x,y)) FROM nodes where id = 161));
 -- ERROR:  Distance is too short. only 1 vertex for alpha shape calculation. alpha shape calculation needs at least 3 vertices.
 
 PREPARE q2 AS
-SELECT * FROM pgr_alphaShape('select * from nodes where id in (160,161)');
+SELECT * FROM pgr_alphaShape((SELECT ST_Collect(ST_MakePoint(x,y)) FROM nodes where id IN (160, 161)));
 -- ERROR:  Error computing shape: After eliminating duplicated points, less than 3 points remain!!
 
 PREPARE q3 AS
-SELECT * FROM pgr_alphaShape('select * from nodes');
+SELECT * FROM pgr_alphaShape((SELECT ST_Collect(ST_MakePoint(x,y)) FROM nodes));
 
-SELECT throws_ok('q1',
- 'XX000', 'Less than 3 vertices. Alpha shape calculation needs at least 3 vertices.',
- 'SHOULD THROW, because there is only one point');
+SELECT CASE WHEN _pgr_versionless((SELECT boost from pgr_full_version()), '1.54.0')
+    THEN skip('pgr_alphaSahpe not supported when compiled with Boost version < 1.54.0', 3 )
+    ELSE collect_tap(
 
-SELECT throws_ok('q2',
- 'XX000','After eliminating duplicated points, less than 3 points remain!!. Alpha shape calculation needs at least 3 vertices.',
- 'SHOULD THROW, because there are less than 3 distinc points');
+        throws_ok('q1',
+            'XX000','Less than 3 vertices. pgr_alphaShape needs at least 3 vertices.',
+            'SHOULD THROW, because there is only one point'),
 
-SELECT lives_ok('q3', 'SHOULD LIVE because ater eliminating duplicates there are enough points to work with');
+        throws_ok('q2',
+            'XX000','Less than 3 vertices. pgr_alphaShape needs at least 3 vertices.',
+            'SHOULD THROW, because there are less than 3 distinc points'),
+
+        lives_ok('q3', 'SHOULD LIVE because ater eliminating duplicates there are enough points to work with')
+
+        )
+    END;
 
 
 -- Finish the tests and clean up.
