@@ -2,10 +2,11 @@
 
 /*
 Data from
-Benchmark tests with data from:
-https://github.com/plotly/documentation/blob/source-design-merge/_posts/python/scientific/alpha-shapes/data-ex-2d.txt
-https://plot.ly/python/alpha-shapes/
+Benchmark test with data from:
+https://github.com/plotly/graphing-library-docs/blob/master/_posts/python-v3/scientific/alpha-shapes/data-ex-2d.txt
+https://plotly.com/python/v3/alpha-shapes/
 */
+UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
 SELECT plan(147);
 
 
@@ -58,12 +59,16 @@ SELECT alphaShape_tester('e_test', 'geom', 0.23, false, 0.5178261889305, 26);
 SELECT alphaShape_tester('e_test', 'geom', 0.22969, false, 0.5178261889305, 26);
 
 
--- best alpha
-SELECT set_eq(
-    $$SELECT round(st_area(pgr_alphaShape)::numeric, 12) FROM pgr_alphaShape((SELECT ST_Collect(geom) FROM e_test))$$,
-    $$SELECT round(st_area(pgr_alphaShape)::numeric, 12) FROM pgr_alphaShape((SELECT ST_Collect(geom) FROM e_test), 0)$$,
-    'SHOULD BE: best alpha obtined with spoon radius 0'
-);
+SELECT CASE WHEN _pgr_versionless((SELECT boost from pgr_full_version()), '1.54.0')
+    THEN skip('pgr_alphaSahpe not supported when compiled with Boost version < 1.54.0', 1 )
+    ELSE
+        -- best alpha
+        set_eq(
+            $$SELECT round(st_area(pgr_alphaShape)::numeric, 12) FROM pgr_alphaShape((SELECT ST_Collect(geom) FROM e_test))$$,
+            $$SELECT round(st_area(pgr_alphaShape)::numeric, 12) FROM pgr_alphaShape((SELECT ST_Collect(geom) FROM e_test), 0)$$,
+            'SHOULD BE: best alpha obtined with spoon radius 1')
+
+    END;
 
 -- best alpha range
 SELECT alphaShape_tester('e_test', 'geom', 0.22968, false, 0.495862454676, 27);
