@@ -27,7 +27,7 @@ SELECT plan(68);
 
 SET client_min_messages TO ERROR;
 
-UPDATE edge_table SET cost = cost + 0.001 * id * id, reverse_cost = reverse_cost + 0.001 * id * id;
+UPDATE edge_table SET cost = sign(cost) + 0.001 * id * id, reverse_cost = sign(reverse_cost) + 0.001 * id * id;
 
 CREATE or REPLACE FUNCTION astarCompareDijkstra(cant INTEGER default 17)
 RETURNS SETOF TEXT AS
