@@ -23,7 +23,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 \i setup.sql
 
-SELECT plan(99);
+UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
+SELECT plan(116);
 SET client_min_messages TO ERROR;
 
 
@@ -90,6 +91,9 @@ BEGIN
 
     query := start_sql || parameter || '::FLOAT8 ' || end_sql;
     RETURN query SELECT throws_ok(query);
+
+    query := start_sql || parameter || '::NUMERIC ' || end_sql;
+    RETURN query SELECT throws_ok(query);
 END;
 $BODY$ LANGUAGE plpgsql;
 
@@ -124,6 +128,9 @@ BEGIN
 
     query := start_sql || parameter || '::FLOAT8 ' || end_sql;
     RETURN query SELECT lives_ok(query);
+
+    query := start_sql || parameter || '::NUMERIC ' || end_sql;
+    RETURN query SELECT lives_ok(query);
 END;
 $BODY$ LANGUAGE plpgsql;
 
