@@ -4,7 +4,7 @@ SET client_min_messages TO ERROR;
 
 SELECT plan(544);
 
-UPDATE edge_table SET cost = cost + 0.001 * id * id, reverse_cost = reverse_cost + 0.001 * id * id;
+UPDATE edge_table SET cost = sign(cost) + 0.001 * id * id, reverse_cost = sign(reverse_cost) + 0.001 * id * id;
 
 
 CREATE or REPLACE FUNCTION bdastar_compare_dijkstra(cant INTEGER default 17)
