@@ -1,7 +1,8 @@
 
 \i setup.sql
 
-SELECT plan(10);
+UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
+SELECT plan(8);
 
 
 SELECT has_function('pgr_bdastar',
@@ -10,9 +11,6 @@ SELECT function_returns('pgr_bdastar',
     ARRAY['text', 'bigint', 'bigint', 'boolean', 'integer', 'numeric', 'numeric'],
     'setof record','Returns set record');
 
-SELECT has_function('pgr_bdastar',ARRAY['text', 'bigint', 'bigint']);
-SELECT function_returns('pgr_bdastar', ARRAY['text', 'bigint', 'bigint'], 'setof record','Returns set record');
-
 
 SELECT throws_ok(
     $$SELECT * FROM pgr_bdastar('SELECT * FROM edge_table',
