@@ -1,9 +1,9 @@
 
 \i setup.sql
 
+UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
 SELECT plan(30);
 
-SELECT todo_start();
 
 -- auxiliary
 SELECT hasnt_function('pgr_flipedges');
@@ -45,8 +45,6 @@ SELECT hasnt_function('pgr_maxflowpushrelable');
 SELECT hasnt_function('pgr_maxflowedmondskarp');
 SELECT hasnt_function('pgr_maximumcardinalitymatching');
 
-SELECT todo_end();
-
 
 
 SELECT finish();
