@@ -1,29 +1,30 @@
 \i setup.sql
 
+UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
 SELECT plan(36);
 
 SET client_min_messages TO WARNING;
 
 PREPARE qempty AS
-SELECT * FROM ( VALUES (-1, 'v', -1, '{}', -1, -1, -1) ) AS t(seq, type, id, contracted_vertices, source, target, cost) WHERE 1 != 1 ;
+SELECT * FROM ( VALUES ('v', -1, '{}', -1, -1, -1) ) AS t(type, id, contracted_vertices, source, target, cost) WHERE 1 != 1 ;
 
 -- TESTING CONTRACTION CYCLE WITH ONLY DEAD END CONTRACTION
 
 -- SINGLE EDGE
 PREPARE v2e1q10 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1',
     ARRAY[1]::integer[], 1, ARRAY[]::integer[], false);
 
 PREPARE v2e1q11 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1',
     ARRAY[1, 1]::integer[], 1, ARRAY[]::integer[], false);
 
 SELECT set_eq('v2e1q10', 'v2e1q11', '1: Undirected graph with single edge and no forbidden vertices');
 
 PREPARE v2e1q12 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1',
     ARRAY[1]::integer[], 2, ARRAY[]::integer[], false);
 
@@ -32,19 +33,19 @@ SELECT set_eq('v2e1q11', 'v2e1q12', '1: Undirected graph with single edge and no
 
 -- TWO EDGES
 PREPARE v3e2q10 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 2',
     ARRAY[1]::integer[], 1, ARRAY[]::integer[], false);
 
 PREPARE v3e2q11 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 2',
     ARRAY[1, 1]::integer[], 1, ARRAY[]::integer[], false);
 
 SELECT set_eq('v3e2q10', 'v3e2q11', '1: Undirected graph with single edge and no forbidden vertices');
 
 PREPARE v3e2q12 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 2',
     ARRAY[1]::integer[], 2, ARRAY[]::integer[], false);
 
@@ -52,19 +53,19 @@ SELECT set_eq('v3e2q10', 'v3e2q12', '1: Undirected graph with single edge and no
 SELECT set_eq('v3e2q11', 'v3e2q12', '1: Undirected graph with single edge and no forbidden vertices');
 
 PREPARE v3e2q13 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 4 or id = 5',
     ARRAY[1]::integer[], 1, ARRAY[]::integer[], false);
 
 PREPARE v3e2q14 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 4 or id = 5',
     ARRAY[1, 1]::integer[], 1, ARRAY[]::integer[], false);
 
 SELECT set_eq('v3e2q13', 'v3e2q14', '4: Undirected graph with two edges and no forbidden vertices');
 
 PREPARE v3e2q15 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 4 or id = 5',
     ARRAY[1]::integer[], 2, ARRAY[]::integer[], false);
 
@@ -73,19 +74,19 @@ SELECT set_eq('v3e2q14', 'v3e2q15', '4: Undirected graph with two edges and no f
 
 -- THREE EDGES
 PREPARE v4e3q10 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 2 or id = 3',
     ARRAY[1]::integer[], 1, ARRAY[]::integer[], false);
 
 PREPARE v4e3q11 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 2 or id = 3',
     ARRAY[1, 1]::integer[], 1, ARRAY[]::integer[], false);
 
 SELECT set_eq('v4e3q10', 'v4e3q11', '5: Undirected graph with three edges and no forbidden vertices');
 
 PREPARE v4e3q12 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 2 or id = 3',
     ARRAY[1]::integer[], 2, ARRAY[]::integer[], false);
 
@@ -93,19 +94,19 @@ SELECT set_eq('v4e3q10', 'v4e3q12', '5: Undirected graph with three edges and no
 SELECT set_eq('v4e3q11', 'v4e3q12', '5: Undirected graph with three edges and no forbidden vertices');
 
 PREPARE v4e3q13 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 4 or id = 5 or id = 6',
     ARRAY[1]::integer[], 1, ARRAY[]::integer[], false);
 
 PREPARE v4e3q14 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 4 or id = 5 or id = 6',
     ARRAY[1, 1]::integer[], 1, ARRAY[]::integer[], false);
 
 SELECT set_eq('v4e3q13', 'v4e3q14', '7: Undirected graph with three edges and no forbidden vertices');
 
 PREPARE v4e3q15 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 4 or id = 5 or id = 6',
     ARRAY[1]::integer[], 2, ARRAY[]::integer[], false);
 
@@ -115,19 +116,19 @@ SELECT set_eq('v4e3q14', 'v4e3q15', '7: Undirected graph with three edges and no
 -- FOUR EDGES
 
 PREPARE v4e4q10 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 4 or id = 5 or id = 6 or id = 8',
     ARRAY[1]::integer[], 1, ARRAY[]::integer[], false);
 
 PREPARE v4e4q11 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 4 or id = 5 or id = 6 or id = 8',
     ARRAY[1, 1]::integer[], 1, ARRAY[]::integer[], false);
 
 SELECT set_eq('v4e4q10', 'v4e4q11', '9: Undirected graph with four edges and no forbidden vertices');
 
 PREPARE v4e4q12 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 4 or id = 5 or id = 6 or id = 8',
     ARRAY[1]::integer[], 2, ARRAY[]::integer[], false);
 
@@ -135,19 +136,19 @@ SELECT set_eq('v4e4q10', 'v4e4q12', '9: Undirected graph with four edges and no
 SELECT set_eq('v4e4q11', 'v4e4q12', '9: Undirected graph with four edges and no forbidden vertices');
 
 PREPARE v6e4q10 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 2 or id = 3 or id = 4',
     ARRAY[1]::integer[], 1, ARRAY[]::integer[], false);
 
 PREPARE v6e4q11 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 2 or id = 3 or id = 4',
     ARRAY[1, 1]::integer[], 1, ARRAY[]::integer[], false);
 
 SELECT set_eq('v6e4q10', 'v6e4q11', '11: Directed graph with four edges and no forbidden vertices');
 
 PREPARE v6e4q12 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 2 or id = 3 or id = 4',
     ARRAY[1]::integer[], 2, ARRAY[]::integer[], false);
 
@@ -159,19 +160,19 @@ SELECT set_eq('v6e4q11', 'v6e4q12', '11: Directed graph with four edges and no f
 
 -- TWO EDGES
 PREPARE v3e2q20 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 2',
     ARRAY[2]::integer[], 1, ARRAY[]::integer[], false);
 
 PREPARE v3e2q21 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 2',
     ARRAY[2, 2]::integer[], 1, ARRAY[]::integer[], false);
 
 SELECT set_eq('v3e2q20', 'v3e2q21', '1: Undirected graph with two edges and no forbidden vertices');
 
 PREPARE v3e2q22 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 2',
     ARRAY[2]::integer[], 2, ARRAY[]::integer[], false);
 
@@ -179,19 +180,19 @@ SELECT set_eq('v3e2q20', 'v3e2q22', '1: Undirected graph with two edges and no f
 SELECT set_eq('v3e2q21', 'v3e2q22', '1: Undirected graph with two edges and no forbidden vertices');
 
 PREPARE v3e2q23 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 4 or id = 5',
     ARRAY[2]::integer[], 1, ARRAY[]::integer[], false);
 
 PREPARE v3e2q24 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 4 or id = 5',
     ARRAY[2, 2]::integer[], 1, ARRAY[]::integer[], false);
 
 SELECT set_eq('v3e2q23', 'v3e2q24', '1: Undirected graph with two edges and no forbidden vertex');
 
 PREPARE v3e2q25 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 4 or id = 5',
     ARRAY[2]::integer[], 2, ARRAY[]::integer[], false);
 
@@ -201,19 +202,19 @@ SELECT set_eq('v3e2q24', 'v3e2q25', '1: Undirected graph with two edges and no f
 -- THREE EDGES
 
 PREPARE v4e3q20 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 2 or id = 3',
     ARRAY[2]::integer[], 1, ARRAY[]::integer[], false);
 
 PREPARE v4e3q21 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 2 or id = 3',
     ARRAY[2, 2]::integer[], 1, ARRAY[]::integer[], false);
 
 SELECT set_eq('v4e3q20', 'v4e3q21', '5: Undirected graph with three edges and no forbidden vertices');
 
 PREPARE v4e3q22 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 2 or id = 3',
     ARRAY[2]::integer[], 2, ARRAY[]::integer[], false);
 
@@ -223,19 +224,19 @@ SELECT set_eq('v4e3q21', 'v4e3q22', '5: Undirected graph with three edges and no
 
 -- FOUR EDGES
 PREPARE v4e4q20 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 9 or id = 10 or id = 11',
     ARRAY[2]::integer[], 1, ARRAY[]::integer[], false);
 
 PREPARE v4e4q21 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 9 or id = 10 or id = 11',
     ARRAY[2, 2]::integer[], 1, ARRAY[]::integer[], false);
 
 SELECT set_eq('v4e4q20', 'v4e4q21', '5: Undirected graph with four edges and no forbidden vertices');
 
 PREPARE v4e4q22 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 1 or id = 9 or id = 10 or id = 11',
     ARRAY[2]::integer[], 2, ARRAY[]::integer[], false);
 
@@ -243,19 +244,19 @@ SELECT set_eq('v4e4q20', 'v4e4q22', '5: Undirected graph with four edges and no
 SELECT set_eq('v4e4q21', 'v4e4q22', '5: Undirected graph with four edges and no forbidden vertices');
 
 PREPARE v4e4q23 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 2 or id = 9 or id = 12 or id = 13',
     ARRAY[2]::integer[], 1, ARRAY[]::integer[], false);
 
 PREPARE v4e4q24 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 2 or id = 9 or id = 12 or id = 13',
     ARRAY[2, 2]::integer[], 1, ARRAY[]::integer[], false);
 
 SELECT set_eq('v4e4q23', 'v4e4q24', '5: Directed graph with four edges and no forbidden vertices');
 
 PREPARE v4e4q25 AS
-SELECT * FROM pgr_contractgraph(
+SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id = 2 or id = 9 or id = 12 or id = 13',
     ARRAY[2]::integer[], 2, ARRAY[]::integer[], false);
 
