@@ -1,5 +1,6 @@
 \i setup.sql
 
+UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
 SELECT plan(7);
 
 PREPARE edges AS
@@ -24,7 +25,7 @@ BEGIN
     'NULL::BIGINT[]'
     ]::TEXT[];
 
-    RETURN query SELECT * FROM no_crash_test('pgr_contractGraph', params, subs);
+    RETURN query SELECT * FROM no_crash_test('pgr_contraction', params, subs);
 
 END
 $BODY$
