@@ -1,5 +1,6 @@
 \i setup.sql
 
+UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
 SELECT plan(3);
 
 PREPARE q1 AS
@@ -7,18 +8,18 @@ SELECT * FROM pgr_dijkstra( 'select id, source, target, cost from edge_table',
     array[2,7], array[5,6]);
 
 PREPARE q2 AS
-SELECT * FROM pgr_dijkstra( 'select id, source, target, cost from edge_table', 
+SELECT * FROM pgr_dijkstra( 'select id, source, target, cost from edge_table',
     array[2,7], array[17,18]);
 
 Prepare q3 AS
 (SELECT * FROM pgr_dijkstra( 'select id, source, target, cost from edge_table',
         array[2,7], array[5,6]))
 UNION
-(SELECT * FROM pgr_dijkstra( 'select id, source, target, cost from edge_table', 
+(SELECT * FROM pgr_dijkstra( 'select id, source, target, cost from edge_table',
         array[2,7], array[17,18]));
 
 PREPARE q4 AS
-SELECT * FROM pgr_dijkstra( 'select id, source, target, cost from edge_table', 
+SELECT * FROM pgr_dijkstra( 'select id, source, target, cost from edge_table',
     array[2,7], array[5,6,17,18]);
 
 SELECT is_empty( 'q2', '1');
