@@ -2,7 +2,7 @@
 
 SELECT plan(36);
 
-UPDATE edge_table SET cost = cost + 0.001 * id * id, reverse_cost = reverse_cost + 0.001 * id * id;
+UPDATE edge_table SET cost = sign(cost) + 0.001 * id * id, reverse_cost = sign(reverse_cost) + 0.001 * id * id;
 
 
 create or REPLACE FUNCTION foo(cant INTEGER default 18, flag boolean default true )
