@@ -1,6 +1,7 @@
 \i setup.sql
 SET client_min_messages TO WARNING;
 
+UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
 SELECT plan(7);
 
 
@@ -44,7 +45,7 @@ SELECT set_eq('mcm_q', 'mcm_v','Expected returning, columns names & types');
 -- testing column names
 SELECT bag_has(
     $$SELECT  proargnames from pg_proc where proname = 'pgr_maxcardinalitymatch'$$,
-    $$SELECT  '{"edges_sql","directed","seq","edge","source","target"}'::TEXT[] $$
+    $$SELECT  '{"","directed","seq","edge","source","target"}'::TEXT[] $$
 );
 
 
