@@ -1,7 +1,7 @@
 \i setup.sql
     SELECT plan(1);
 
-    UPDATE edge_table SET cost = cost + 0.001 * id * id, reverse_cost = reverse_cost + 0.001 * id * id;
+    UPDATE edge_table SET cost = sign(cost) + 0.001 * id * id, reverse_cost = sign(reverse_cost) + 0.001 * id * id;
 
     prepare q1 AS
     SELECT seq, id1, id2, cost::TEXT FROM pgr_trsp(
