@@ -1,6 +1,7 @@
 
 \i setup.sql
 
+UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
 SELECT plan(28);
 SET client_min_messages TO WARNING;
 
@@ -26,7 +27,7 @@ SELECT function_returns('pgr_tsp', ARRAY[
 
 PREPARE parameters AS
 SELECT array[
-'matrix_row_sql',
+'',
 'start_id','end_id','max_processing_time',
 'tries_per_temperature',
 'max_changes_per_temperature',
