@@ -22,39 +22,24 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
+--------------------
+-- pgr_bdAstar
+--------------------
 
 
--- V3
-CREATE OR REPLACE FUNCTION pgr_bdAstar(
-    TEXT,
-    BIGINT,
-    BIGINT,
-    OUT seq INTEGER,
-    OUT path_seq INTEGER,
-    OUT node BIGINT,
-    OUT edge BIGINT,
-    OUT cost FLOAT,
-    OUT agg_cost FLOAT)
-RETURNS SETOF RECORD AS
-$BODY$
-    SELECT a.seq, a.path_seq, a.node, a.edge, a.cost, a.agg_cost
-    FROM _pgr_bdAstar(_pgr_get_statement($1), ARRAY[$2]::BIGINT[], ARRAY[$3]::BIGINT[], directed:=true, only_cost:=false) AS a;
-$BODY$
-LANGUAGE sql VOLATILE STRICT
-COST 100
-ROWS 1000;
+-- one to one
+--v2.6
+CREATE FUNCTION pgr_bdAstar(
+    TEXT,   -- edges_sql (required)
+    BIGINT, -- from_vid (required)
+    BIGINT, -- to_vid (required)
 
-
--- V3
-CREATE OR REPLACE FUNCTION pgr_bdAstar(
-    TEXT,
-    BIGINT,
-    BIGINT,
-    BOOLEAN,
+    directed BOOLEAN DEFAULT true,
     heuristic INTEGER DEFAULT 5,
     factor NUMERIC DEFAULT 1.0,
     epsilon NUMERIC DEFAULT 1.0,
+
     OUT seq INTEGER,
     OUT path_seq INTEGER,
     OUT node BIGINT,
@@ -71,14 +56,17 @@ COST 100
 ROWS 1000;
 
 -- one to many
-CREATE OR REPLACE FUNCTION pgr_bdAstar(
-    TEXT,
-    BIGINT,
-    ANYARRAY,
+--v2.6
+CREATE FUNCTION pgr_bdAstar(
+    TEXT,     -- edges_sql (required)
+    BIGINT,   -- from_vid (required)
+    ANYARRAY, -- to_vids (required)
+
     directed BOOLEAN DEFAULT true,
     heuristic INTEGER DEFAULT 5,
     factor NUMERIC DEFAULT 1.0,
     epsilon NUMERIC DEFAULT 1.0,
+
     OUT seq INTEGER,
     OUT path_seq INTEGER,
     OUT end_vid BIGINT,
@@ -96,14 +84,17 @@ COST 100
 ROWS 1000;
 
 -- many to one
-CREATE OR REPLACE FUNCTION pgr_bdAstar(
-    TEXT,
-    ANYARRAY,
-    BIGINT,
+--v2.6
+CREATE FUNCTION pgr_bdAstar(
+    TEXT,     -- edges_sql (required)
+    ANYARRAY, -- from_vids (required)
+    BIGINT,   -- to_vid (required)
+
     directed BOOLEAN DEFAULT true,
     heuristic INTEGER DEFAULT 5,
     factor NUMERIC DEFAULT 1.0,
     epsilon NUMERIC DEFAULT 1.0,
+
     OUT seq INTEGER,
     OUT path_seq INTEGER,
     OUT start_vid BIGINT,
@@ -121,14 +112,17 @@ COST 100
 ROWS 1000;
 
 -- many to many
-CREATE OR REPLACE FUNCTION pgr_bdAstar(
-    TEXT,
-    ANYARRAY,
-    ANYARRAY,
+--v2.6
+CREATE FUNCTION pgr_bdAstar(
+    TEXT,     -- edges_sql (required)
+    ANYARRAY, -- from_vids (required)
+    ANYARRAY, -- to_vids (required)
+
     directed BOOLEAN DEFAULT true,
     heuristic INTEGER DEFAULT 5,
     factor NUMERIC DEFAULT 1.0,
     epsilon NUMERIC DEFAULT 1.0,
+
     OUT seq INTEGER,
     OUT path_seq INTEGER,
     OUT start_vid BIGINT,
@@ -146,11 +140,65 @@ LANGUAGE sql VOLATILE STRICT
 COST 100
 ROWS 1000;
 
-
 -- COMMENTS
 
-COMMENT ON FUNCTION pgr_bdAstar(TEXT, BIGINT, BIGINT) IS 'pgr_bdAstar(One to One)';
-COMMENT ON FUNCTION pgr_bdAstar(TEXT, BIGINT, BIGINT, BOOLEAN, INTEGER, NUMERIC, NUMERIC) IS 'pgr_bdAstar(One to One)';
-COMMENT ON FUNCTION pgr_bdAstar(TEXT, ANYARRAY, BIGINT, BOOLEAN, INTEGER, NUMERIC, NUMERIC) IS 'pgr_bdAstar(Many to One)';
-COMMENT ON FUNCTION pgr_bdAstar(TEXT, BIGINT, ANYARRAY, BOOLEAN, INTEGER, NUMERIC, NUMERIC) IS 'pgr_bdAstar(One to Many)';
-COMMENT ON FUNCTION pgr_bdAstar(TEXT, ANYARRAY, ANYARRAY, BOOLEAN, INTEGER, NUMERIC, NUMERIC) IS 'pgr_bdAstar(Many to Many)';
+COMMENT ON FUNCTION pgr_bdAstar(TEXT, BIGINT, BIGINT, BOOLEAN, INTEGER, NUMERIC, NUMERIC)
+IS 'pgr_bdAstar(One to One)
+- Parameters:
+  - edges SQL with columns: id, source, target, cost [,reverse_cost], x1, y1, x2, y2
+  - From vertex identifier
+  - To vertex identifier
+- Optional Parameters:
+  - directed := true
+  - heuristic := 5
+  - factor := 1
+  - epsilon := 1
+- Documentation:
+  - ${PROJECT_DOC_LINK}/pgr_bdAstar.html
+';
+
+COMMENT ON FUNCTION pgr_bdAstar(TEXT, BIGINT, ANYARRAY, BOOLEAN, INTEGER, NUMERIC, NUMERIC)
+IS 'pgr_bdAstar(One to Many)
+- Parameters:
+  - edges SQL with columns: id, source, target, cost [,reverse_cost], x1, y1, x2, y2
+  - From vertex identifier
+  - To ARRAY[vertices identifiers]
+- Optional Parameters:
+  - directed := true
+  - heuristic := 5
+  - factor := 1
+  - epsilon := 1
+- Documentation:
+  - ${PROJECT_DOC_LINK}/pgr_bdAstar.html
+';
+
+
+COMMENT ON FUNCTION pgr_bdAstar(TEXT, ANYARRAY, BIGINT, BOOLEAN, INTEGER, NUMERIC, NUMERIC)
+IS 'pgr_bdAstar(Many to One)
+- Parameters:
+  - edges SQL with columns: id, source, target, cost [,reverse_cost], x1, y1, x2, y2
+  - From ARRAY[vertices identifiers]
+  - To vertex identifier
+- Optional Parameters:
+  - directed := true
+  - heuristic := 5
+  - factor := 1
+  - epsilon := 1
+- Documentation:
+  - ${PROJECT_DOC_LINK}/pgr_bdAstar.html
+';
+
+COMMENT ON FUNCTION pgr_bdAstar(TEXT, ANYARRAY, ANYARRAY, BOOLEAN, INTEGER, NUMERIC, NUMERIC)
+IS 'pgr_bdAstar(Many to Many)
+- Parameters:
+  - edges SQL with columns: id, source, target, cost [,reverse_cost], x1, y1, x2, y2
+  - From ARRAY[vertices identifiers]
+  - To ARRAY[vertices identifiers]
+- Optional Parameters:
+  - directed := true
+  - heuristic := 5
+  - factor := 1
+  - epsilon := 1
+- Documentation:
+  - ${PROJECT_DOC_LINK}/pgr_bdAstar.html
+';
