@@ -22,18 +22,24 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
 
+--------------------
+-- pgr_bdAstarCost
+--------------------
 
 -- one to one
-CREATE OR REPLACE FUNCTION pgr_bdAstarCost(
-    TEXT,
-    BIGINT,
-    BIGINT,
+--v2.6
+CREATE FUNCTION pgr_bdAstarCost(
+    TEXT,   -- edges_sql (required)
+    BIGINT, -- from_vid (required)
+    BIGINT, -- to_vid (required)
+
     directed BOOLEAN DEFAULT true,
     heuristic INTEGER DEFAULT 5,
     factor NUMERIC DEFAULT 1.0,
     epsilon NUMERIC DEFAULT 1.0,
+
     OUT start_vid BIGINT,
     OUT end_vid BIGINT,
     OUT agg_cost FLOAT)
@@ -46,15 +52,19 @@ LANGUAGE sql VOLATILE STRICT
 COST 100
 ROWS 1000;
 
+
 -- one to many
-CREATE OR REPLACE FUNCTION pgr_bdAstarCost(
-    TEXT,
-    BIGINT,
-    ANYARRAY,
+--v2.6
+CREATE FUNCTION pgr_bdAstarCost(
+    TEXT,     -- edges_sql (required)
+    BIGINT,   -- from_vid (required)
+    ANYARRAY, -- to_vidd (required)
+
     directed BOOLEAN DEFAULT true,
     heuristic INTEGER DEFAULT 5,
     factor NUMERIC DEFAULT 1.0,
     epsilon NUMERIC DEFAULT 1.0,
+
     OUT start_vid BIGINT,
     OUT end_vid BIGINT,
     OUT agg_cost FLOAT)
@@ -67,15 +77,19 @@ LANGUAGE sql VOLATILE STRICT
 COST 100
 ROWS 1000;
 
+
 -- many to one
-CREATE OR REPLACE FUNCTION pgr_bdAstarCost(
-    TEXT,
-    ANYARRAY,
-    BIGINT,
+--v2.6
+CREATE FUNCTION pgr_bdAstarCost(
+    TEXT,     -- edges_sql (required)
+    ANYARRAY, -- from_vids (required)
+    BIGINT,   -- to_vid (required)
+
     directed BOOLEAN DEFAULT true,
     heuristic INTEGER DEFAULT 5,
     factor NUMERIC DEFAULT 1.0,
     epsilon NUMERIC DEFAULT 1.0,
+
     OUT start_vid BIGINT,
     OUT end_vid BIGINT,
     OUT agg_cost FLOAT)
@@ -88,15 +102,20 @@ LANGUAGE sql VOLATILE STRICT
 COST 100
 ROWS 1000;
 
+
+
 -- many to many
-CREATE OR REPLACE FUNCTION pgr_bdAstarCost(
-    TEXT,
-    ANYARRAY,
-    ANYARRAY,
+--v2.6
+CREATE FUNCTION pgr_bdAstarCost(
+    TEXT,     -- edges_sql (required)
+    ANYARRAY, -- from_vids (required)
+    ANYARRAY, -- to_vids (required)
+
     directed BOOLEAN DEFAULT true,
     heuristic INTEGER DEFAULT 5,
     factor NUMERIC DEFAULT 1.0,
     epsilon NUMERIC DEFAULT 1.0,
+
     OUT start_vid BIGINT,
     OUT end_vid BIGINT,
     OUT agg_cost FLOAT)
@@ -112,7 +131,65 @@ ROWS 1000;
 
 -- COMMENTS
 
-COMMENT ON FUNCTION pgr_bdAstarCost(TEXT, BIGINT, BIGINT, BOOLEAN, INTEGER, NUMERIC, NUMERIC) IS 'pgr_bdAstarCost(One to One)';
-COMMENT ON FUNCTION pgr_bdAstarCost(TEXT, BIGINT, ANYARRAY, BOOLEAN, INTEGER, NUMERIC, NUMERIC) IS 'pgr_bdAstarCost(One to Many)';
-COMMENT ON FUNCTION pgr_bdAstarCost(TEXT, ANYARRAY, BIGINT, BOOLEAN, INTEGER, NUMERIC, NUMERIC) IS 'pgr_bdAstarCost(Many to One)';
-COMMENT ON FUNCTION pgr_bdAstarCost(TEXT, ANYARRAY, ANYARRAY, BOOLEAN, INTEGER, NUMERIC, NUMERIC) IS 'pgr_bdAstarCost(Many to Many)';
+COMMENT ON FUNCTION pgr_bdAstarCost(TEXT, BIGINT, BIGINT, BOOLEAN, INTEGER, NUMERIC, NUMERIC)
+IS 'pgr_bdAstarCost(One to One)
+- Parameters:
+  - edges SQL with columns: id, source, target, cost [,reverse_cost], x1, y1, x2, y2
+  - From vertex identifier
+  - To vertex identifier
+- Optional Parameters:
+  - directed := true
+  - heuristic := 5
+  - factor := 1
+  - epsilon := 1
+- Documentation:
+  - ${PROJECT_DOC_LINK}/pgr_bdAstarCost.html
+';
+
+
+COMMENT ON FUNCTION pgr_bdAstarCost(TEXT, BIGINT, ANYARRAY, BOOLEAN, INTEGER, NUMERIC, NUMERIC)
+IS 'pgr_bdAstarCost(One to Many)
+- Parameters:
+  - edges SQL with columns: id, source, target, cost [,reverse_cost], x1, y1, x2, y2
+  - From vertex identifier
+  - To ARRAY[vertices identifiers]
+- Optional Parameters:
+  - directed := true
+  - heuristic := 5
+  - factor := 1
+  - epsilon := 1
+- Documentation:
+  - ${PROJECT_DOC_LINK}/pgr_bdAstarCost.html
+';
+
+
+COMMENT ON FUNCTION pgr_bdAstarCost(TEXT, ANYARRAY, BIGINT, BOOLEAN, INTEGER, NUMERIC, NUMERIC)
+IS 'pgr_bdAstarCost(Many to One)
+- Parameters:
+  - edges SQL with columns: id, source, target, cost [,reverse_cost], x1, y1, x2, y2
+  - From ARRAY[vertices identifiers]
+  - To vertex identifier
+- Optional Parameters:
+  - directed := true
+  - heuristic := 5
+  - factor := 1
+  - epsilon := 1
+- Documentation:
+  - ${PROJECT_DOC_LINK}/pgr_bdAstarCost.html
+';
+
+
+COMMENT ON FUNCTION pgr_bdAstarCost(TEXT, ANYARRAY, ANYARRAY, BOOLEAN, INTEGER, NUMERIC, NUMERIC)
+IS 'pgr_bdAstarCost(Many to Many)
+- Parameters:
+  - edges SQL with columns: id, source, target, cost [,reverse_cost], x1, y1, x2, y2
+  - From ARRAY[vertices identifiers]
+  - To ARRAY[vertices identifiers]
+- Optional Parameters:
+  - directed := true
+  - heuristic := 5
+  - factor := 1
+  - epsilon := 1
+- Documentation:
+  - ${PROJECT_DOC_LINK}/pgr_bdAstarCost.html
+';
