@@ -21,7 +21,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
 
 
 /************************************************************************
@@ -50,7 +50,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 ************************************************************************/
 
-CREATE OR REPLACE FUNCTION _pgr_onError(
+--v2.6
+CREATE FUNCTION _pgr_onError(
   IN errCond boolean,  -- true there is an error
   IN reportErrs int,   -- 0, 1 or 2
   IN fnName text,      -- function name that generates the error
@@ -78,6 +79,10 @@ END;
 $BODY$
 LANGUAGE plpgsql VOLATILE STRICT;
 
+COMMENT ON FUNCTION _pgr_onError(BOOLEAN, INTEGER, TEXT, TEXT, TEXT, TEXT)
+IS 'pgRouting internal function';
+
+
 /************************************************************************
 .. function:: _pgr_msg(msgKind, fnName, msg)
 
@@ -99,7 +104,8 @@ LANGUAGE plpgsql VOLATILE STRICT;
 
 ************************************************************************/
 
-CREATE OR REPLACE FUNCTION _pgr_msg(IN msgKind int, IN fnName text, IN msg text default '---->OK')
+--v2.6
+CREATE FUNCTION _pgr_msg(IN msgKind int, IN fnName text, IN msg text default '---->OK')
   RETURNS void AS
 $BODY$
 BEGIN
@@ -112,6 +118,8 @@ END;
 $BODY$
 LANGUAGE plpgsql VOLATILE STRICT;
 
+COMMENT ON FUNCTION _pgr_msg(INTEGER, TEXT, TEXT)
+IS 'pgRouting internal function';
 
 /************************************************************************
 .. function:: _pgr_getColumnType(sname,tname,col,reportErrs,fnName) returns text
@@ -134,7 +142,8 @@ LANGUAGE plpgsql VOLATILE STRICT;
      Created: 2014/JUL/28
 ************************************************************************/
 
-CREATE OR REPLACE FUNCTION _pgr_getColumnType(sname text, tname text, cname text,
+--v2.6
+CREATE FUNCTION _pgr_getColumnType(sname text, tname text, cname text,
      IN reportErrs int default 0, IN fnName text default '_pgr_getColumnType')
 RETURNS text AS
 $BODY$
@@ -161,7 +170,8 @@ $BODY$
 LANGUAGE plpgsql VOLATILE STRICT;
 
 
-CREATE OR REPLACE FUNCTION _pgr_getColumnType(tab text, col text,
+--v2.6
+CREATE FUNCTION _pgr_getColumnType(tab text, col text,
      IN reportErrs int default 0, IN fnName text default '_pgr_getColumnType')
 RETURNS text AS
 $BODY$
@@ -186,6 +196,11 @@ $BODY$
 LANGUAGE plpgsql VOLATILE STRICT;
 
 
+COMMENT ON FUNCTION _pgr_getColumnType(TEXT, TEXT, TEXT, INTEGER, TEXT)
+IS 'pgRouting internal function';
+
+COMMENT ON FUNCTION _pgr_getColumnType(TEXT, TEXT, INTEGER, TEXT)
+IS 'pgRouting internal function';
 
 
 
@@ -204,7 +219,8 @@ LANGUAGE plpgsql VOLATILE STRICT;
   HISTORY
      Created: 2014/JUL/27
 ************************************************************************/
-CREATE OR REPLACE FUNCTION _pgr_get_statement(o_sql text)
+--v2.6
+CREATE FUNCTION _pgr_get_statement(o_sql text)
 RETURNS text AS
 $BODY$
 DECLARE
@@ -220,6 +236,8 @@ END
 $BODY$
 LANGUAGE plpgsql STABLE STRICT;
 
+COMMENT ON FUNCTION _pgr_get_statement(TEXT)
+IS 'pgRouting internal function';
 
 /************************************************************************
 .. function:: _pgr_checkVertTab(vertname,columnsArr,reportErrs) returns record of sname,vname
@@ -239,7 +257,8 @@ LANGUAGE plpgsql STABLE STRICT;
   HISTORY
      Created: 2014/JUL/27
 ************************************************************************/
-CREATE OR REPLACE FUNCTION _pgr_checkVertTab(vertname text, columnsArr  text[],
+--v2.6
+CREATE FUNCTION _pgr_checkVertTab(vertname text, columnsArr  text[],
     IN reportErrs int default 1, IN fnName text default '_pgr_checkVertTab',
     OUT sname text,OUT vname text)
 RETURNS record AS
@@ -286,3 +305,6 @@ BEGIN
 $BODY$
 LANGUAGE plpgsql VOLATILE STRICT;
 
+COMMENT ON FUNCTION _pgr_checkVertTab(TEXT, TEXT[], INTEGER, TEXT)
+IS 'pgRouting internal function';
+
