@@ -34,7 +34,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ---------------
 ---------------
 
-CREATE OR REPLACE FUNCTION _pgr_dijkstra(
+--v3.0
+CREATE FUNCTION _pgr_dijkstra(
     edges_sql TEXT,
     start_vids ANYARRAY,
     end_vids ANYARRAY,
@@ -56,7 +57,8 @@ RETURNS SETOF RECORD AS
 LANGUAGE C VOLATILE STRICT;
 
 
-CREATE OR REPLACE FUNCTION _pgr_dijkstra(
+--v3.1
+CREATE FUNCTION _pgr_dijkstra(
     edges_sql TEXT,
     combinations_sql TEXT,
     directed BOOLEAN DEFAULT true,
