@@ -33,7 +33,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ---------------
 
 -- ONE to ONE
-CREATE OR REPLACE FUNCTION pgr_dijkstra(
+--v2.6
+CREATE FUNCTION pgr_dijkstra(
     TEXT,   -- edges_sql (required)
     BIGINT, -- from_vid (required)
     BIGINT, -- to_vid (required)
@@ -56,7 +57,8 @@ COST 100
 ROWS 1000;
 
 -- ONE to MANY
-CREATE OR REPLACE FUNCTION pgr_dijkstra(
+--v2.6
+CREATE FUNCTION pgr_dijkstra(
     TEXT,     -- edges_sql (required)
     BIGINT,   -- from_vid (required)
     ANYARRAY, -- to_vids (required)
@@ -80,7 +82,8 @@ COST 100
 ROWS 1000;
 
 -- MANY to ONE
-CREATE OR REPLACE FUNCTION pgr_dijkstra(
+--v2.6
+CREATE FUNCTION pgr_dijkstra(
     TEXT,     -- edges_sql (required)
     ANYARRAY, -- from_vids (required)
     BIGINT,   -- to_vid (required)
@@ -104,7 +107,8 @@ COST 100
 ROWS 1000;
 
 -- MANY to MANY
-CREATE OR REPLACE FUNCTION pgr_dijkstra(
+--v2.6
+CREATE FUNCTION pgr_dijkstra(
     TEXT,     -- edges_sql (required)
     ANYARRAY, -- from_vids (required)
     ANYARRAY, -- to_vids (required)
@@ -129,7 +133,8 @@ COST 100
 ROWS 1000;
 
 -- Combinations SQL signature
-CREATE OR REPLACE FUNCTION pgr_dijkstra(
+--v3.1
+CREATE FUNCTION pgr_dijkstra(
     TEXT,     -- edges_sql (required)
     TEXT,     -- combinations_sql (required)
 
@@ -164,7 +169,7 @@ IS 'pgr_dijkstra(One to One)
 - Optional Parameters
    - directed := true
 - Documentation:
-   - ${PGROUTING_DOC_LINK}/pgr_dijkstra.html
+   - ${PROJECT_DOC_LINK}/pgr_dijkstra.html
 ';
 
 COMMENT ON FUNCTION pgr_dijkstra(TEXT, BIGINT, ANYARRAY, BOOLEAN)
@@ -176,7 +181,7 @@ IS 'pgr_dijkstra(One to Many)
 - Optional Parameters
    - directed := true
 - Documentation:
-   - ${PGROUTING_DOC_LINK}/pgr_dijkstra.html
+   - ${PROJECT_DOC_LINK}/pgr_dijkstra.html
 ';
 
 COMMENT ON FUNCTION pgr_dijkstra(TEXT, ANYARRAY, BIGINT, BOOLEAN)
@@ -188,7 +193,7 @@ IS 'pgr_dijkstra(Many to One)
 - Optional Parameters
    - directed := true
 - Documentation:
-   - ${PGROUTING_DOC_LINK}/pgr_dijkstra.html
+   - ${PROJECT_DOC_LINK}/pgr_dijkstra.html
 ';
 
 COMMENT ON FUNCTION pgr_dijkstra(TEXT, ANYARRAY, ANYARRAY, BOOLEAN)
@@ -200,7 +205,7 @@ IS 'pgr_dijkstra(Many to Many)
 - Optional Parameters
    - directed := true
 - Documentation:
-   - ${PGROUTING_DOC_LINK}/pgr_dijkstra.html
+   - ${PROJECT_DOC_LINK}/pgr_dijkstra.html
 ';
 
 COMMENT ON FUNCTION pgr_dijkstra(TEXT, TEXT, BOOLEAN)
@@ -211,5 +216,5 @@ IS 'pgr_dijkstra(One to One)
 - Optional Parameters
    - directed := true
 - Documentation:
-   - ${PGROUTING_DOC_LINK}/pgr_dijkstra.html
+   - ${PROJECT_DOC_LINK}/pgr_dijkstra.html
 ';
