@@ -22,24 +22,26 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
 
 ------------------------------------
--- 1 pgr_pushRelabel
+-- pgr_pushRelabel
 ------------------------------------
 
 
-CREATE OR REPLACE FUNCTION pgr_pushRelabel(
-    TEXT,
-    BIGINT,
-    BIGINT,
+-- ONE to ONE
+--v2.6
+CREATE FUNCTION pgr_pushRelabel(
+    TEXT, -- edges_sql (required)
+    BIGINT, -- from_vid (required)
+    BIGINT, -- to_vid (required)
+
     OUT seq INTEGER,
     OUT edge BIGINT,
     OUT start_vid BIGINT,
     OUT end_vid BIGINT,
     OUT flow BIGINT,
-    OUT residual_capacity BIGINT
-    )
+    OUT residual_capacity BIGINT)
   RETURNS SETOF RECORD AS
   $BODY$
         SELECT *
@@ -48,18 +50,19 @@ CREATE OR REPLACE FUNCTION pgr_pushRelabel(
   LANGUAGE sql VOLATILE STRICT;
 
 
+-- ONE to MANY
+--v2.6
+CREATE FUNCTION pgr_pushRelabel(
+    TEXT, -- edges_sql (required)
+    BIGINT, -- from_vid (required)
+    ANYARRAY, -- to_vids (required)
 
-CREATE OR REPLACE FUNCTION pgr_pushRelabel(
-    TEXT,
-    BIGINT,
-    ANYARRAY,
     OUT seq INTEGER,
     OUT edge BIGINT,
     OUT start_vid BIGINT,
     OUT end_vid BIGINT,
     OUT flow BIGINT,
-    OUT residual_capacity BIGINT
-    )
+    OUT residual_capacity BIGINT)
   RETURNS SETOF RECORD AS
   $BODY$
         SELECT *
@@ -68,18 +71,19 @@ CREATE OR REPLACE FUNCTION pgr_pushRelabel(
   LANGUAGE sql VOLATILE STRICT;
 
 
+-- MANY to ONE
+--v2.6
+CREATE FUNCTION pgr_pushRelabel(
+    TEXT, -- edges_sql (required)
+    ANYARRAY, -- from_vids (required)
+    BIGINT, -- to_vid (required)
 
-CREATE OR REPLACE FUNCTION pgr_pushRelabel(
-    TEXT,
-    ANYARRAY,
-    BIGINT,
     OUT seq INTEGER,
     OUT edge BIGINT,
     OUT start_vid BIGINT,
     OUT end_vid BIGINT,
     OUT flow BIGINT,
-    OUT residual_capacity BIGINT
-    )
+    OUT residual_capacity BIGINT)
   RETURNS SETOF RECORD AS
   $BODY$
         SELECT *
@@ -88,17 +92,19 @@ CREATE OR REPLACE FUNCTION pgr_pushRelabel(
   LANGUAGE sql VOLATILE STRICT;
 
 
-CREATE OR REPLACE FUNCTION pgr_pushRelabel(
-    TEXT,
-    ANYARRAY,
-    ANYARRAY,
+-- MANY to MANY
+--v2.6
+CREATE FUNCTION pgr_pushRelabel(
+    TEXT, -- edges_sql (required)
+    ANYARRAY, -- from_vids (required)
+    ANYARRAY, -- to_vids (required)
+
     OUT seq INTEGER,
     OUT edge BIGINT,
     OUT start_vid BIGINT,
     OUT end_vid BIGINT,
     OUT flow BIGINT,
-    OUT residual_capacity BIGINT
-    )
+    OUT residual_capacity BIGINT)
   RETURNS SETOF RECORD AS
   $BODY$
         SELECT *
@@ -106,3 +112,53 @@ CREATE OR REPLACE FUNCTION pgr_pushRelabel(
   $BODY$
   LANGUAGE sql VOLATILE STRICT;
 
+
+-- COMMENTS
+
+
+COMMENT ON FUNCTION pgr_pushRelabel(TEXT, BIGINT, BIGINT)
+IS 'pgr_pushRelabel(One to One)
+- Directed graph
+- Parameters:
+  - Edges SQL with columns: id, source, target, capacity [,reverse_capacity]
+  - From vertex identifier
+  - To vertex identifier
+- Documentation:
+  - ${PROJECT_DOC_LINK}/pgr_pushRelabel.html
+';
+
+
+COMMENT ON FUNCTION pgr_pushRelabel(TEXT, BIGINT, ANYARRAY)
+IS 'pgr_pushRelabel(One to Many)
+- Directed graph
+- Parameters:
+  - Edges SQL with columns: id, source, target, capacity [,reverse_capacity]
+  - From vertex identifie
+  - To ARRAY[vertices identifiers]
+- Documentation:
+  - ${PROJECT_DOC_LINK}/pgr_pushRelabel.html
+';
+
+
+COMMENT ON FUNCTION pgr_pushRelabel(TEXT, ANYARRAY, BIGINT)
+IS 'pgr_pushRelabel(Many to One)
+- Directed graph
+- Parameters:
+  - Edges SQL with columns: id, source, target, capacity [,reverse_capacity]
+  - From ARRAY[vertices identifiers]
+  - To vertex identifie
+- Documentation:
+  - ${PROJECT_DOC_LINK}/pgr_pushRelabel.html
+';
+
+
+COMMENT ON FUNCTION pgr_pushRelabel(TEXT, ANYARRAY, ANYARRAY)
+IS 'pgr_pushRelabel(Many to Many)
+- Directed graph
+- Parameters:
+  - Edges SQL with columns: id, source, target, capacity [,reverse_capacity]
+  - From ARRAY[vertices identifiers]
+  - To ARRAY[vertices identifiers]
+- Documentation:
+  - ${PROJECT_DOC_LINK}/pgr_pushRelabel.html
+';
