@@ -25,7 +25,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  ********************************************************************PGR-GNU*/
 
 
-CREATE OR REPLACE FUNCTION pgr_extractVertices(
+--v3.0
+CREATE FUNCTION pgr_extractVertices(
     TEXT,  -- SQL inner query (required)
 
     dryrun BOOLEAN DEFAULT false,
@@ -368,5 +369,5 @@ IS 'pgr_extractVertices
         OR
   - Edges SQL with columns: [id,] geom
 - Documentation:
-- ${PGROUTING_DOC_LINK}/pgr_extractVertices.html
+- ${PROJECT_DOC_LINK}/pgr_extractVertices.html
 ';
