@@ -20,12 +20,17 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
 
--------------------------------
--- trsp: one to one
--------------------------------
-CREATE OR REPLACE FUNCTION _pgr_trsp(
+
+--------------
+-- _pgr_trsp
+--------------
+
+
+-- ONE to ONE
+--v2.6
+CREATE FUNCTION _pgr_trsp(
     TEXT, -- edges_sql
     TEXT, -- restrictions_sql
     BIGINT, -- start_vid
@@ -54,10 +59,9 @@ COST 100
 ROWS 1000;
 
 
--------------------------------
--- trsp: one to many
--------------------------------
-CREATE OR REPLACE FUNCTION _pgr_trsp(
+-- ONE to MANY
+--v2.6
+CREATE FUNCTION _pgr_trsp(
     TEXT, -- edges_sql
     TEXT, -- restrictions_sql
     BIGINT, -- start_vid
@@ -87,10 +91,9 @@ COST 100
 ROWS 1000;
 
 
--------------------------------
--- trsp: many to one
--------------------------------
-CREATE OR REPLACE FUNCTION _pgr_trsp(
+-- MANY to ONE
+--v2.6
+CREATE FUNCTION _pgr_trsp(
     TEXT, -- edges_sql
     TEXT, -- restrictions_sql
     ANYARRAY, -- start_vids
@@ -119,10 +122,10 @@ LANGUAGE sql VOLATILE STRICT
 COST 100
 ROWS 1000;
 
--------------------------------
--- trsp: many to many
--------------------------------
-CREATE OR REPLACE FUNCTION _pgr_trsp(
+
+-- MANY to MANY
+--v2.6
+CREATE FUNCTION _pgr_trsp(
     TEXT, -- edges_sql
     TEXT, -- restrictions_sql
     ANYARRAY, -- start_vids
@@ -152,3 +155,22 @@ LANGUAGE sql VOLATILE STRICT
 COST 100
 ROWS 1000;
 
+
+-- COMMENTS
+
+
+COMMENT ON FUNCTION _pgr_trsp(TEXT, TEXT, BIGINT, BIGINT, BOOLEAN)
+IS 'pgRouting internal function';
+
+
+COMMENT ON FUNCTION _pgr_trsp(TEXT, TEXT, BIGINT, ANYARRAY, BOOLEAN)
+IS 'pgRouting internal function';
+
+
+COMMENT ON FUNCTION _pgr_trsp(TEXT, TEXT, ANYARRAY, BIGINT, BOOLEAN)
+IS 'pgRouting internal function';
+
+
+COMMENT ON FUNCTION _pgr_trsp(TEXT, TEXT, ANYARRAY, ANYARRAY, BOOLEAN)
+IS 'pgRouting internal function';
+
