@@ -20,14 +20,13 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
 
 #include "c_common/arrays_input.h"
 
 #include <assert.h>
-#include "utils/lsyscache.h"
-#include "catalog/pg_type.h"
-
+#include <utils/lsyscache.h>
+#include <catalog/pg_type.h>
 
 #include "c_common/time_msg.h"
 #include "c_common/debug_macro.h"
