@@ -37,8 +37,20 @@ namespace pgrouting {
 namespace vrp {
 
 
+Pgr_pickDeliver* Fleet::problem;
+
+/**
+* @returns reference to the problem's message
+*/
+Pgr_messages&
+Fleet::msg() {
+    return problem->msg;
+}
+
+
+
+
 Fleet::Fleet(const Fleet &fleet) :
-    PD_problem(),
     m_trucks(fleet.m_trucks),
     used(fleet.used),
     un_used(fleet.un_used)
@@ -46,7 +58,6 @@ Fleet::Fleet(const Fleet &fleet) :
 
 Fleet::Fleet(
         const std::vector<Vehicle_t> &vehicles, double factor) :
-    PD_problem(),
     used(),
     un_used() {
         build_fleet(vehicles, factor);
@@ -57,15 +68,15 @@ Fleet::Fleet(
 
 Vehicle_pickDeliver
 Fleet::get_truck() {
-    ENTERING();
+    ENTERING(msg());
     auto idx = un_used.front();
-    msg.log << "Available vehicles: " << un_used << "\n";
-    msg.log << "NOT Available vehicles: " << used << "\n";
-    msg.log << "getting idx" << idx << "\n";
-    pgassertwm(idx < m_trucks.size(), msg.log.str());
+    msg().log << "Available vehicles: " << un_used << "\n";
+    msg().log << "NOT Available vehicles: " << used << "\n";
+    msg().log << "getting idx" << idx << "\n";
+    pgassertwm(idx < m_trucks.size(), msg().log.str());
     used += idx;
     if (un_used.size() > 1) un_used -= idx;
-    EXITING();
+    EXITING(msg());
     return m_trucks[idx];
 }
 
@@ -77,14 +88,16 @@ Fleet::release_truck(size_t id) {
 
 Vehicle_pickDeliver
 Fleet::get_truck(size_t order) {
-    msg.log << "Available vehicles: " << un_used << "\n";
-    msg.log << "NOT Available vehicles: " << used << "\n";
+#if 0
+    msg().log << "Available vehicles: " << un_used << "\n";
+    msg().log << "NOT Available vehicles: " << used << "\n";
+#endif
     auto idx = un_used.front();
 
-    for (const auto i : un_used) {
+    for (const auto &i : un_used) {
         if (m_trucks[i].feasable_orders().has(order)) {
             idx = i;
-            msg.log << "getting idx" << idx << "\n";
+            msg().log << "getting idx" << idx << "\n";
             used += idx;
             if (un_used.size() > 1) un_used -= idx;
             return m_trucks[idx];
@@ -100,8 +113,8 @@ Fleet::get_truck(size_t order) {
     for (auto truck : m_trucks) {
         if (truck.feasable_orders().has(order)) {
             idx = truck.idx();
-            msg.log << "idx" << idx << "size" << m_trucks.size();
-            pgassertwm(idx < m_trucks.size(), msg.get_log());
+            msg().log << "idx" << idx << "size" << m_trucks.size();
+            pgassertwm(idx < m_trucks.size(), msg().get_log());
             used += idx;
             if (un_used.size() > 1) un_used -= idx;
             break;
@@ -117,9 +130,9 @@ Fleet::get_truck(const Order order) {
     for (auto truck : m_trucks) {
         if (truck.feasable_orders().has(order.idx())) {
             id = truck.idx();
-            msg.log << "id" << id
+            msg().log << "id" << id
                 << "size" << m_trucks.size();
-            pgassertwm(id < m_trucks.size(), msg.get_log());
+            pgassertwm(id < m_trucks.size(), msg().get_log());
             used += id;
             if (un_used.size() > 1) un_used -= id;
             break;
@@ -133,18 +146,18 @@ void
 Fleet::add_vehicle(
         Vehicle_t vehicle,
         double factor,
-        std::unique_ptr<Base_node> b_start,
         const Vehicle_node &starting_site,
-        std::unique_ptr<Base_node> b_end,
         const Vehicle_node &ending_site) {
     pgassert(starting_site.is_start() && ending_site.is_end());
     pgassert(starting_site.opens() <= starting_site.closes());
     pgassert(ending_site.opens() <= ending_site.closes());
 
+#if 0
     problem->add_base_node(std::move(b_start));
     problem->add_base_node(std::move(b_end));
     problem->add_node(starting_site);
     problem->add_node(ending_site);
+#endif
 
     for (int i = 0; i < vehicle.cant_v; ++i) {
         m_trucks.push_back(Vehicle_pickDeliver(
@@ -155,14 +168,16 @@ Fleet::add_vehicle(
                     vehicle.capacity,
                     vehicle.speed,
                     factor));
-        msg.log << "inserting vehicle: " << m_trucks.back().tau() << "\n";
+#if 0
+        msg().log << "inserting vehicle: " << m_trucks.back().tau() << "\n";
+#endif
         pgassert((m_trucks.back().idx() + 1)  == m_trucks.size());
         pgassert(m_trucks.back().is_ok());
     }
 }
 
 /*!
-  builds a fleet from a vector of Vehicle_t 
+  builds a fleet from a vector of Vehicle_t
 
   - creates a phoney truck with unlimited capacity and unlimited closing times
   - checks that the number of vehicles is a legal value
@@ -212,12 +227,47 @@ Fleet::build_fleet(
 
     for (auto vehicle : vehicles) {
         if (vehicle.cant_v < 0) {
-            msg.error << "Illegal number of vehicles found vehicle";
-            msg.log << vehicle.cant_v << "< 0 on vehicle " << vehicle.id;
-            return false;
+            throw std::make_pair(std::string("Illegal number of vehicles found"), vehicle.cant_v);
         }
 
+        if (vehicle.capacity < 0) {
+            throw std::make_pair(std::string("Illegal value for capacity found"), vehicle.capacity);
+        }
+
+        if  (!problem->m_cost_matrix.empty()) {
+            if (!problem->m_cost_matrix.has_id(vehicle.start_node_id)) {
+                throw std::make_pair(std::string("Unable to find node on matrix"), vehicle.start_node_id);
+            }
+            if (!problem->m_cost_matrix.has_id(vehicle.end_node_id)) {
+                throw std::make_pair(std::string("Unable to find node on matrix"), vehicle.end_node_id);
+            }
+        }
+
+        if (!(vehicle.start_open_t  <= vehicle.start_close_t
+                    && vehicle.end_open_t <= vehicle.end_close_t
+                    && vehicle.start_open_t <= vehicle.end_close_t)) {
+            msg().error << "Illegal values found on vehicle";
+            msg().log << "On vehicle " << vehicle.id
+                << " a condition is not met, verify that:"
+                << "\nvehicle.start_open_t  <= vehicle.start_close_t\t"
+                << vehicle.start_open_t << " <= " << vehicle.start_close_t
+                << "\nvehicle.end_open_t <= vehicle.end_close_t\t"
+                << vehicle.end_open_t << " <= " << vehicle.end_close_t
+                << "\nvehicle.start_open_t <= vehicle.end_close_t\t"
+                << vehicle.start_open_t << " <= " << vehicle.end_close_t;
+
+            throw std::make_pair(msg().get_error(), msg().get_log());
+        }
+#if 0
+        if (vehicle.cant_v < 0) {
+            msg().error << "Illegal number of vehicles found vehicle";
+            msg().log << vehicle.cant_v << "< 0 on vehicle " << vehicle.id;
+            return false;
+        }
+#endif
+
         if  (problem->m_cost_matrix.empty()) {
+#if 0
             /*
              * Euclidean version
              */
@@ -232,9 +282,9 @@ Fleet::build_fleet(
             if (!(starting_site.is_start() && ending_site.is_end()
                     && starting_site.opens() <= starting_site.closes()
                     && ending_site.opens() <= ending_site.closes())) {
-                msg.clear();
-                msg.error << "Illegal values found on vehicle";
-                msg.log << "On vehicle " << vehicle.id
+                msg().clear();
+                msg().error << "Illegal values found on vehicle";
+                msg().log << "On vehicle " << vehicle.id
                     << " a condition is not met:\n"
                     << "starting_site.is_start: "
                     << (starting_site.is_start()? "YES" : "NO") << "\n"
@@ -248,7 +298,7 @@ Fleet::build_fleet(
                     << ending_site.opens()
                     << "<"  << ending_site.closes() << "\n"
                     << "-  capacity > 0\n";
-                pgassert(!msg.get_error().empty());
+                pgassert(!msg().get_error().empty());
                 return false;
             }
             pgassert(starting_site.is_start());
@@ -258,14 +308,16 @@ Fleet::build_fleet(
             pgassert(ending_site.opens() <= ending_site.closes());
             pgassertwm(
                     starting_site.is_start() && ending_site.is_end(),
-                    msg.get_error().c_str());
+                    msg().get_error().c_str());
             add_vehicle(vehicle, factor,
                     std::move(b_start), starting_site,
                     std::move(b_end), ending_site);
+#endif
         } else {
             /*
              * Matrix version
              */
+#if 0
             auto b_start = create_b_start<Dnode>(vehicle, problem->node_id());
             auto starting_site = Vehicle_node(
                     {problem->node_id()++, vehicle, Tw_node::NodeType::kStart});
@@ -277,9 +329,9 @@ Fleet::build_fleet(
             if (!(starting_site.is_start() && ending_site.is_end()
                     && starting_site.opens() <= starting_site.closes()
                     && ending_site.opens() <= ending_site.closes())) {
-                msg.clear();
-                msg.error << "Illegal values found on vehicle";
-                msg.log << "On vehicle " << vehicle.id
+                msg().clear();
+                msg().error << "Illegal values found on vehicle";
+                msg().log << "On vehicle " << vehicle.id
                     << " a condition is not met, verify that:\n"
                     << "starting_site.is_start()"
                     << starting_site.is_start() << "\n"
@@ -292,18 +344,23 @@ Fleet::build_fleet(
                     << ending_site.opens() << "<"
                     << ending_site.closes() << "\n"
                     << "-  capacity > 0\n";
-                pgassert(!msg.get_error().empty());
+                pgassert(!msg().get_error().empty());
                 return false;
             }
             pgassert(starting_site.is_start());
             pgassert(ending_site.is_end());
 
+#endif
+            auto starting_site = Vehicle_node({problem->m_nodes.size(), vehicle, Tw_node::NodeType::kStart});
+            problem->add_node(starting_site);
+            auto ending_site = Vehicle_node({problem->m_nodes.size(), vehicle, Tw_node::NodeType::kEnd});
+            problem->add_node(ending_site);
+
             pgassert(starting_site.opens() <= starting_site.closes());
             pgassert(ending_site.opens() <= ending_site.closes());
             pgassert(starting_site.is_start() && ending_site.is_end());
-            add_vehicle(vehicle, factor,
-                    std::move(b_start), starting_site,
-                    std::move(b_end), ending_site);
+
+            add_vehicle(vehicle, factor, starting_site, ending_site);
         }
     }
     Identifiers<size_t> unused(m_trucks.size());
@@ -314,12 +371,12 @@ Fleet::build_fleet(
 
 bool
 Fleet::is_fleet_ok() const {
-    ENTERING();
-    if (!msg.get_error().empty()) return false;
+    ENTERING(msg());
+    if (!msg().get_error().empty()) return false;
     for (auto truck : m_trucks) {
         if (!truck.is_ok()) {
-            msg.error << "Illegal values found on vehicle";
-            msg.log << "On vehicle " << truck.id()
+            msg().error << "Illegal values found on vehicle";
+            msg().log << "On vehicle " << truck.id()
                 << " a condition is not met, verify that:\n"
                 << "-  start_open <= start_close\n"
                 << "-  end_open <= end_close\n"
@@ -330,15 +387,15 @@ Fleet::is_fleet_ok() const {
         if (!(truck.start_site().is_start()
                     && truck.end_site().is_end())) {
             pgassertwm(false, "should never pass through here");
-            msg.error << "Illegal values found on vehicle";
+            msg().error << "Illegal values found on vehicle";
             return false;
         }
         if (!truck.is_feasable()) {
-            msg.error << "Truck is not feasible";
+            msg().error << "Truck is not feasible";
             return false;
         }
     }
-    EXITING();
+    EXITING(msg());
     return true;
 }
 
@@ -349,7 +406,7 @@ Fleet::is_fleet_ok() const {
  */
 bool
 Fleet::is_order_ok(const Order &order) const {
-    for (const auto truck : m_trucks) {
+    for (const auto &truck : m_trucks) {
         if (!order.is_valid(truck.speed())) continue;
         if (truck.is_order_feasable(order)) {
             return true;
@@ -378,7 +435,7 @@ Fleet::set_compatibles(const PD_Orders &orders) {
 std::ostream&
 operator << (std::ostream &log, const Fleet &f) {
     log << "fleet\n";
-    for (const auto v : f.m_trucks) {
+    for (const auto &v : f.m_trucks) {
         log << v;
     }
     log << "end fleet\n";
