@@ -42,6 +42,17 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 namespace pgrouting {
 namespace vrp {
 
+Pgr_pickDeliver* Vehicle::problem;
+
+/**
+* @returns reference to the problem's message
+*/
+Pgr_messages&
+Vehicle::msg() {
+    return problem->msg;
+}
+
+
 
 void
 Vehicle::invariant() const {
@@ -137,8 +148,8 @@ Vehicle::get_postgres_result(
     std::vector<General_vehicle_orders_t> result;
     /* postgres numbering starts with 1 */
     int stop_seq(1);
-    msg.log << "getting solution: " << tau() << "\n";
-    for (const auto p_stop : m_path) {
+    msg().log << "getting solution: " << tau() << "\n";
+    for (const auto &p_stop : m_path) {
         General_vehicle_orders_t data = {
             vid,
             id(),
@@ -175,7 +186,7 @@ Vehicle::insert(POS at, Vehicle_node node) {
     invariant();
     pgassert(at <= m_path.size());
 
-    m_path.insert(m_path.begin() + at, node);
+    m_path.insert(m_path.begin() + static_cast<difference_type>(at), node);
     evaluate(at);
 
     pgassert(at < m_path.size());
@@ -319,7 +330,7 @@ Vehicle::erase(POS at) {
     pgassert(!m_path[at].is_start());
     pgassert(!m_path[at].is_end());
 
-    m_path.erase(m_path.begin() + at);
+    m_path.erase(m_path.begin() + static_cast<difference_type>(at));
     evaluate(at);
 
     invariant();
@@ -356,6 +367,12 @@ Vehicle::empty() const {
     return m_path.size() <= 2;
 }
 
+size_t
+Vehicle::size() const {
+    invariant();
+    return m_path.size() - 2;
+}
+
 void
 Vehicle::evaluate(POS from) {
     invariant();
@@ -363,7 +380,7 @@ Vehicle::evaluate(POS from) {
     pgassert(from < m_path.size());
 
 
-    auto node = m_path.begin() + from;
+    auto node = m_path.begin() + static_cast<difference_type>(from);
 
     while (node != m_path.end()) {
         if (node == m_path.begin()) {
@@ -391,6 +408,45 @@ Vehicle::position_limits(const Vehicle_node node) const {
     return std::make_pair(low, high);
 }
 
+std::pair<size_t, size_t>
+Vehicle::drop_position_limits(const Vehicle_node node) const {
+    POS high = getPosHighLimit(node);
+    POS low = getDropPosLowLimit(node);
+    return std::make_pair(low, high);
+}
+
+/*
+ * start searching from postition low = pos(E)
+ *
+ * S 1 2 3 4 5 6 7 ..... E
+ * node -> E
+ * node -> ...
+ * node -> 7
+ * node -> 6
+ * node -> 5
+ * node /-> 4
+ *
+ * return low_limit = 5
+ *
+ */
+size_t
+Vehicle::getDropPosLowLimit(const Vehicle_node &nodeI) const {
+    invariant();
+
+    POS low = 0;
+    POS high = m_path.size();
+    POS low_limit = high;
+
+    /* J == m_path[low_limit - 1] */
+    while (low_limit > low
+            && m_path[low_limit - 1].is_compatible_IJ(nodeI, speed())
+            && !m_path[low_limit - 1].is_pickup()) {
+        --low_limit;
+    }
+
+    invariant();
+    return low_limit;
+}
 
 /*
  * start searching from postition low = pos(E)
@@ -478,23 +534,30 @@ Vehicle::Vehicle(
     m_capacity(p_m_capacity),
     m_factor(p_factor),
     m_speed(p_speed) {
+#if 0
         ENTERING();
+#endif
         m_path.clear();
         pgassert(starting_site.opens() <= starting_site.closes());
         pgassert(ending_site.opens() <= ending_site.closes());
         pgassert(capacity() > 0);
-        msg.log << "p_idx: " << p_idx << "\t idx(): " << idx() << "\n";
-        msg.log << "p_id: " << p_id << "\tid(): " << id() << "\n";
+#if 0
+        msg().log << "p_idx: " << p_idx << "\t idx(): " << idx() << "\n";
+        msg().log << "p_id: " << p_id << "\tid(): " << id() << "\n";
+#endif
 
         m_path.push_back(starting_site);
         m_path.push_back(ending_site);
 
         evaluate(0);
-        msg.log << tau() << "\n";
+        msg().log << tau() << "\n";
         invariant();
+#if 0
         EXITING();
+#endif
     }
 
+#if 0
 Vehicle::Vehicle(const Vehicle &v) :
     Identifier(v.idx(), v.id()),
     PD_problem(),
@@ -504,11 +567,12 @@ Vehicle::Vehicle(const Vehicle &v) :
     m_speed(v.m_speed) {
 #if 0
         ENTERING();
-        msg.log << v.tau() << "\n";
-        msg.log << tau() << "\n";
+        msg().log << v.tau() << "\n";
+        msg().log << tau() << "\n";
         EXITING();
 #endif
 }
+#endif
 
 
 
@@ -518,7 +582,7 @@ Vehicle::tau() const {
     std::ostringstream log;
     log << "Truck " << id() << "(" << idx() << ")"
         << " (";
-    for (const auto p_stop : m_path) {
+    for (const auto &p_stop : m_path) {
         if (!(p_stop == m_path.front()))
             log << ", ";
         log << p_stop.id();
@@ -567,7 +631,7 @@ operator<(const Vehicle &lhs, const Vehicle &rhs) {
     /* here because sizes are equal */
 
     if (lhs.m_path.back().total_travel_time()
-            < lhs.m_path.back().total_travel_time()) return true;
+            < rhs.m_path.back().total_travel_time()) return true;
 
     return false;
 }
