@@ -13,13 +13,14 @@ DROP TABLE IF EXISTS edge_table;
 DROP TABLE IF EXISTS edge_table_vertices_pgr;
 DROP table if exists pointsOfInterest;
 DROP TABLE IF EXISTS restrictions;
+DROP TABLE IF EXISTS new_restrictions;
 DROP TABLE IF EXISTS retrict;
 DROP TABLE IF EXISTS vertex_table;
 DROP TABLE IF EXISTS categories;
 DROP TABLE IF EXISTS vehicles;
 DROP TABLE IF EXISTS orders;
 
---EDGE TABLE CREATE
+--EDGE TABLE CREATE start
 CREATE TABLE edge_table (
     id BIGSERIAL,
     dir character varying,
@@ -37,7 +38,8 @@ CREATE TABLE edge_table (
     y2 FLOAT,
     the_geom geometry
 );
---EDGE TABLE ADD DATA
+--EDGE TABLE CREATE end
+--EDGE TABLE ADD DATA start
 INSERT INTO edge_table (
     category_id, reverse_category_id,
     cost, reverse_cost,
@@ -62,6 +64,9 @@ INSERT INTO edge_table (
 (3, 3,    1,  1,  80,  80,   4,   1,    4, 2),
 (1, 2,    1,  1, 130, 100,   0.5, 3.5,  1.999999999999,3.5),
 (4, 1,    1,  1,  50, 130,   3.5, 2.3,  3.5,4);
+--EDGE TABLE ADD DATA end
+
+--EDGE TABLE update geometry start
 
 UPDATE edge_table SET the_geom = st_makeline(st_point(x1,y1),st_point(x2,y2)),
 dir = CASE WHEN (cost>0 AND reverse_cost>0) THEN 'B'   -- both ways
@@ -69,10 +74,13 @@ dir = CASE WHEN (cost>0 AND reverse_cost>0) THEN 'B'   -- both ways
            WHEN (cost<0 AND reverse_cost>0) THEN 'TF'  -- reverse direction of the LINESTRING
            ELSE '' END;                                -- unknown
 
---EDGE TABLE TOPOLOGY
-SELECT pgr_createTopology('edge_table',0.001);
+--EDGE TABLE update geometry end
 
---POINTS CREATE
+--EDGE TABLE TOPOLOGY start
+SELECT pgr_createTopology('edge_table',0.001);
+--EDGE TABLE TOPOLOGY end
+
+--POINTS CREATE start
 CREATE TABLE pointsOfInterest(
     pid BIGSERIAL,
     x FLOAT,
@@ -96,8 +104,9 @@ UPDATE pointsOfInterest SET the_geom = st_makePoint(x,y);
 UPDATE pointsOfInterest
     SET newPoint = ST_LineInterpolatePoint(e.the_geom, fraction)
     FROM edge_table AS e WHERE edge_id = id;
+--POINTS CREATE end
 
---RESTRICTIONS CREATE
+--RESTRICTIONS CREATE start
 CREATE TABLE restrictions (
     rid BIGINT NOT NULL,
     to_cost FLOAT,
@@ -113,33 +122,21 @@ INSERT INTO restrictions (rid, to_cost, target_id, from_edge, via_path) VALUES
 (2,   4,  8,  3, 5),
 (3, 100,  9, 16, NULL);
 
---RESTRICTIONS END
-/*
-CREATE TABLE categories (
-    category_id INTEGER,
-    category text,
-    capacity BIGINT
+CREATE TABLE new_restrictions (
+    id SERIAL PRIMARY KEY,
+    path BIGINT[],
+    cost float
 );
 
-INSERT INTO categories VALUES
-(1, 'Category 1', 130),
-(2, 'Category 2', 100),
-(3, 'Category 3',  80),
-(4, 'Category 4',  50);
-*/
---CATEGORIES END
-
--- TODO check if this table is still used
-CREATE TABLE vertex_table (
-    id SERIAL,
-    x FLOAT,
-    y FLOAT
-);
-INSERT INTO vertex_table VALUES
-(1,2,0), (2,2,1), (3,3,1), (4,4,1), (5,0,2), (6,1,2), (7,2,2),
-(8,3,2), (9,4,2), (10,2,3), (11,3,3), (12,4,3), (13,2,4);
-
---VERTEX TABLE END
+INSERT INTO new_restrictions (path, cost) VALUES
+(ARRAY[4, 7], 100),
+(ARRAY[8, 11], 100),
+(ARRAY[4, 8], 100),
+(ARRAY[5, 9], 100),
+(ARRAY[10, 12], 100),
+(ARRAY[9, 15], 100),
+(ARRAY[3, 5, 8], 100);
+--RESTRICTIONS CREATE end
 
 
 --VEHICLES TABLE START
@@ -200,3 +197,19 @@ INSERT INTO orders
 
 
 --ORDERS TABLE END
+
+--COMBINATIONS CREATE start
+CREATE TABLE combinations_table (
+    source BIGINT,
+    target BIGINT
+);
+
+INSERT INTO combinations_table (
+    source, target) VALUES
+(1, 2),
+(1, 4),
+(2, 1),
+(2, 4),
+(2, 17);
+
+--COMBINATIONS CREATE end
