@@ -13,9 +13,9 @@
 
 SET client_min_messages = WARNING;
 
-CREATE EXTENSION postgis;
-CREATE EXTENSION pgtap;
-CREATE EXTENSION pgrouting;
+CREATE EXTENSION IF NOT EXISTS postgis;
+CREATE EXTENSION IF NOT EXISTS pgtap;
+CREATE EXTENSION IF NOT EXISTS pgrouting;
 
 --    i vrppdtw_data.sql
 --    i pickDeliver_pgtap_data.sql
@@ -23,11 +23,13 @@ BEGIN;
 
     \i sampledata.sql
     \i vrppdtw_data.sql
-    \i vrpOneDepot.data
+    \i solomon_100_rc101.data.sql
     \i innerQuery.sql
     \i innerQuery_old.sql
     \i inner_styles.sql
     \i old_inner_styles.sql
     \i no_crash_test.sql
+    \i alphaShapeTester.sql
+    \i binaryBreadthFirstSearch_pgtap_data.sql
 
 END;
